#! /bin/sh
#
# Name: cc_reject1_a.s
#
# Description:  Ensures that an unrejected ref file does not have any of
#               its rejection fields set.
#
# Called by: cc_reject1.s
#
# Requires:  env var CDBS_SERVER
#            env var CDBS_DB
#
# Usage:     cc_reject1_a.s instrumentPrefix
#
# History:
# 05/04/11  xxxxx  MSwam   ported to Linux/MSSQL and skip over reactivated files
#---------------------------------------------------------------------------
isql -S$CDBS_SERVER << EOF 
use $CDBS_DB
go

/* Check that if reject flag is 'N', then */
/* reject_delivery_number is null */
/* reject_by_file_name is null */
/* reject_by_expansion_number is null */

if exists (select * from $1_file where reject_flag = 'N'
     and (reject_delivery_number is not null or
          reject_by_file_name is not null or
          reject_by_expansion_number is not null) 
     and comment not like 'Reactivated%')
begin
 print '-> CDBS ERROR:'
 print '->  reject information is not null for an unrejected $1 file'
 print '->      file name                                          delivery_number'
 select distinct '->', file_name, delivery_number from $1_file where reject_flag = 'N'
     and  (reject_delivery_number is not null or
          reject_by_file_name is not null or
          reject_by_expansion_number is not null) 
     and comment not like 'Reactivated%'
 print '->'
end
go

