#!/bin/sh
#
# Name: update_ga_date.s
#
# Description: Updates the general availability date for a CDBS deliveryNumber,
#              through a stored procedure.
#
# Called by:   update_ga_date
#
# Requires:    env var CDBS_SERVER
#              env var CDBS_DB
#
# Returns:     0 = if GA date update was successful
#              1 = if update failed
#
#------------------------------------------------------------------------
echo "starting update_ga_date "
echo "database " ${CDBS_DB?"CDBS_ERROR: CDBS_DB is undefined"}
echo "server " ${CDBS_SERVER?"CDBS_ERROR: CDBS_SERVER is undefined"}
date
#
# either use the deliveryNumber argument passed in, or get the current
#  delivery number from the database
#
if test $# -lt 1
then
  delivery_number=`get_current_delivery_number.s | awk '/^ *[0-9]/{print $1}'`
else
  # passed as argument
  delivery_number=$1
fi
echo "delivery number = " $delivery_number
#
# Execute the stored procedure to update the general availability date
res=`update_ga_date_sql.s $CDBS_DB $delivery_number`

if test `echo $res | grep "OK" | wc -l` -ne 0
then
  echo "general availability date was updated"
  exit 0
fi
echo $res
exit 1

