// REFFILE.H -- Structure and templates for reference file reading routines

#ifndef REFFILE_H
#define REFFILE_H

#include "config.h"

#define  name_reffile(ref)	((ref)->name)
#define  kind_reffile(ref)	((ref)->type)
#define  inbody_reffile(ref)	((ref)->row > 0)
#define  row_reffile(ref)	((ref)->row)

#define  FILETYPE_NAMES		"image|table|loadfile"

#define  UNRECOGNIZED		0
#define  IMAGE			1
#define  TABLE			2
#define  LOADFILE		3

typedef struct {
  char	name[SZ_FNAME+1];   // name of the file
  int	type;               // image, table, or loadfile
  int	mode;               // file open mode (r,w,etc.)
  int	is_fits;            // flags a FITS file
  int	smudge;             // flags an updated file
  int	row;                // current table row/FITS extension
  void *ptr;
} reffile;

extern int	access_reffile (char *, char *, char *);
extern void    	close_reffile (reffile *);
extern int	get_body_reffile (reffile *, char *, int, char *, int);
extern int	get_hdr_reffile (reffile *, char *, char *, int);
extern int	nrow_reffile (reffile *);
extern reffile  *open_reffile (char *, char *, char *);
extern reffile  *open_reffile_hdr (char *, char *, char *);
extern reffile  *open_reffile_body (char *, char *, char *);
extern void	put_body_reffile (reffile *, char *, int, char *);
extern void	put_hdr_reffile (reffile *, char *, char *);
extern void	put_hist_reffile (reffile *, char *, char *);
extern int	rename_reffile (char *, char *, char *);
extern char     *type_reffile (char *, char *);

#endif
