create trigger foc_file_insert
on foc_file 
for insert as
begin
  declare @rel_info_type char(1)      /* relation_info.type, I(image) or T(table) */

  if (select count(*) from inserted) > 1
    begin  /* too many inserts */
      /* display error message */
      print '*******************************************************************'
      print 'CDBS Error: Attempting to insert more than 1 record into foc_file '
      select delivery_number,reference_file_type,file_name,expansion_number,
        useafter_date,opus_flag,opus_load_date,archive_date,
        general_availability_date,reject_flag,reject_delivery_number,
        reject_by_file_name,reject_by_expansion_number from inserted
      print '*******************************************************************'
      print ' '

      rollback transaction
      print 'NO RECORDS WERE INSERTED'
      print ' '
      return
    end /* too many inserts */


  select @rel_info_type = r.type 
    from relation_info r, inserted i
   where r.reference_file_type = i.reference_file_type
     and r.instrument = 'FOC'

  /* Table record */
  if @rel_info_type = 'T'
    begin /* Table record */

      update foc_file
         set foc_file.reject_flag = 'Y',
             foc_file.reject_delivery_number = inserted.delivery_number,
             foc_file.reject_by_file_name = inserted.file_name,
             foc_file.reject_by_expansion_number = inserted.expansion_number
        from foc_file, inserted
       where foc_file.reference_file_type = inserted.reference_file_type
         and foc_file.useafter_date = inserted.useafter_date
         and foc_file.reject_flag = 'N'
         and foc_file.opus_flag = inserted.opus_flag
         and foc_file.file_name != inserted.file_name 
             /* can never reject a file with same file name */
    end  /* Table record */


  /* Image record */
  if @rel_info_type = 'I'
    begin /* Image record */

      /* check existence of corresponding row level record */
      if not exists (select *
            from foc_row, inserted
           where foc_row.file_name = inserted.file_name
             and foc_row.expansion_number = inserted.expansion_number) 
        begin  /* row level record not found */
         
          /* display error message */
          print '*******************************************************************'
          print 'CDBS Error: No row level record for foc_file'
          select file_name, expansion_number from inserted
          print '*******************************************************************'
          print ' '

          /* row_level record not found, reject inserted file_level record */
          rollback transaction
          print 'NO RECORDS WERE INSERTED'
          print ' '
          return
        end /* row level record not found */


      /* set reject record */
      update foc_file
         set foc_file.reject_flag = 'Y',
             foc_file.reject_delivery_number = i.delivery_number,
             foc_file.reject_by_file_name = i.file_name,
             foc_file.reject_by_expansion_number = i.expansion_number
        from foc_file n, inserted i, foc_row r1, foc_row r2
       where n.reference_file_type = i.reference_file_type
         and n.useafter_date = i.useafter_date
         and n.opus_flag = i.opus_flag
         and n.reject_flag = 'N'
         and n.file_name != i.file_name
         and r1.file_name = i.file_name
         and r1.expansion_number = i.expansion_number
         and r1.optcrly = r2.optcrly
         and r1.pxformt = r2.pxformt
         and r1.optelt1 = r2.optelt1
         and r1.optelt1 = r2.optelt2
         and r1.sampoff = r2.sampoff
         and r1.samppln = r2.samppln
         and r1.lineoff = r2.lineoff
         and r1.linepfm = r2.linepfm
         and r1.cammode = r2.cammode
         and r1.smmmode = r2.smmmode
         and r1.wavelength = r2.wavelength
         and n.file_name = r2.file_name
         and n.expansion_number = r2.expansion_number
    end /* Image record */  

  /* insert record to table <opus_log> */
  insert opus_log (delivery_number, file_name, expansion_number, instrument,
      reference_file_type, operation) select delivery_number, file_name,
      expansion_number, 'FOC', reference_file_type, 'I'
      from inserted where opus_flag = 'Y' 

end  /* for insert */

go
