create trigger foc_row_delete
on foc_row
for delete as
begin /* for delete row level data */

  /* check corresponding file level table's general_availability_date */
  /* reject delete if general_availability_date is not null           */
  if exists (select * from foc_file w, deleted d
       where w.file_name = d.file_name and w.expansion_number = d.expansion_number 
         and general_availability_date is not NULL) 
    begin /* foc_file.general_availability_date is not null */

      /* display error message */
      print '*******************************************************************'
      print 'CDBS Error: Attempting to delete foc_row record(s) for delivered data'
      select f.delivery_number,f.reference_file_type,f.file_name,
             f.expansion_number,f.useafter_date,f.opus_flag,f.opus_load_date,
             f.archive_date,f.general_availability_date,f.reject_flag,
             f.reject_delivery_number,f.reject_by_file_name,
             f.reject_by_expansion_number
        from foc_file f, deleted d
       where f.file_name = d.file_name
         and f.expansion_number = d.expansion_number
         and f.general_availability_date is not NULL
      print '*******************************************************************'
      print ' '

      /* rollback deleted foc_row data */
      rollback transaction
      print 'NO RECORDS WERE DELETED'
      print ' '
      return
    end  /* foc_file.general_availability_date is not null */
end  /* for delete row level data */

go
