create trigger fos_file_insert
on fos_file 
for insert as
begin
  declare @rel_info_type char(1)  /* relation_info.type, I(image) or T(table) */
  declare @ref_file_type char(50) /* fos_file.reference_file_type            */

  if (select count(*) from inserted) > 1
    begin  /* too many inserts */
      /* display error message */
      print '*******************************************************************'
      print 'CDBS Error: Attempting to insert more than 1 record into fos_file '
      select delivery_number,reference_file_type,file_name,expansion_number,
        useafter_date,opus_flag,opus_load_date,archive_date,
        general_availability_date,reject_flag,reject_delivery_number,
        reject_by_file_name,reject_by_expansion_number from inserted
      print '*******************************************************************'
      print ' '

      rollback transaction
      print 'NO RECORDS WERE INSERTED'
      print ' '
      return
    end /* too many inserts */


  select @rel_info_type = r.type 
    from relation_info r, inserted i
   where r.reference_file_type = i.reference_file_type
     and r.instrument = 'FOS'

  /* Table record */
  if @rel_info_type = 'T'
    begin /* Table record */

      select @ref_file_type = reference_file_type from inserted

      /* Consider the nonstandard file selection criteria */
      if @ref_file_type = 'CCSE'  /* parmid = 'T' */
         /* set reject record */
         update fos_file
           set fos_file.reject_flag = 'Y',
             fos_file.reject_delivery_number = i.delivery_number,
             fos_file.reject_by_file_name = i.file_name,
             fos_file.reject_by_expansion_number = i.expansion_number
          from fos_file n, inserted i, fos_row r1, fos_row r2
         where n.reference_file_type = i.reference_file_type
           and n.useafter_date = i.useafter_date
           and n.reject_flag = 'N'
           and n.opus_flag = i.opus_flag
           and n.file_name != i.file_name
           and r1.file_name = i.file_name
           and r1.expansion_number = i.expansion_number
           and r1.parmid = r2.parmid
           and n.file_name = r2.file_name
           and n.expansion_number = r2.expansion_number
      else /* All other table cases */
      update fos_file
         set fos_file.reject_flag = 'Y',
             fos_file.reject_delivery_number = inserted.delivery_number,
             fos_file.reject_by_file_name = inserted.file_name,
             fos_file.reject_by_expansion_number = inserted.expansion_number
        from fos_file, inserted
       where fos_file.reference_file_type = inserted.reference_file_type
         and fos_file.useafter_date = inserted.useafter_date
         and fos_file.opus_flag = inserted.opus_flag
         and fos_file.reject_flag = 'N'
         and fos_file.file_name != inserted.file_name 
             /* can never reject a file with same file name */
    end  /* Table record */


  /* Image record */
  if @rel_info_type = 'I'
    begin /* Image record */

      /* check existence of corresponding row level record */
      if not exists (select *
            from fos_row, inserted
           where fos_row.file_name = inserted.file_name
             and fos_row.expansion_number = inserted.expansion_number) 
        begin  /* row level record not found */
         
          /* display error message */
          print '*******************************************************************'
          print 'CDBS Error: No row level record for fos_file'
          select file_name, expansion_number from inserted
          print '*******************************************************************'
          print ' '

          /* row_level record not found, reject inserted file_level record */
          rollback transaction
          print 'NO RECORDS WERE INSERTED'
          print ' '
          return
        end /* row level record not found */


      /* set reject record */
      update fos_file
         set fos_file.reject_flag = 'Y',
             fos_file.reject_delivery_number = i.delivery_number,
             fos_file.reject_by_file_name = i.file_name,
             fos_file.reject_by_expansion_number = i.expansion_number
        from fos_file n, inserted i, fos_row r1, fos_row r2
       where n.reference_file_type = i.reference_file_type
         and n.useafter_date = i.useafter_date
         and n.opus_flag = i.opus_flag
         and n.reject_flag = 'N'
         and n.file_name != i.file_name
         and r1.file_name = i.file_name
         and r1.expansion_number = i.expansion_number
         and r1.detector = r2.detector
         and r1.overscan = r2.overscan
         and r1.aper_id = r2.aper_id
         and r1.aper_pos = r2.aper_pos
         and r1.polar_id = r2.polar_id
         and r1.fgwa_id = r2.fgwa_id
         and r1.pass_dir = r2.pass_dir
         and r1.fchnl = r2.fchnl
         and r1.nxsteps = r2.nxsteps
         and r1.wavelength = r2.wavelength
         and n.file_name = r2.file_name
         and n.expansion_number = r2.expansion_number
    end /* Image record */  

  /* insert record to table <opus_log> */
  insert opus_log (delivery_number, file_name, expansion_number, instrument,
      reference_file_type, operation) select delivery_number, file_name,
      expansion_number, 'FOS', reference_file_type, 'I'
      from inserted where opus_flag = 'Y' 

end

go
