create trigger hrs_row_delete
on hrs_row
for delete as
begin /* for delete row level data */

  /* check corresponding file level table's general_availability_date */
  /* reject delete if general_availability_date is not null           */
  if exists (select * from hrs_file w, deleted d
       where w.file_name = d.file_name and w.expansion_number = d.expansion_number 
         and general_availability_date is not NULL) 
    begin /* hrs_file.general_availability_date is not null */

      /* display error message */
      print '*******************************************************************'
      print 'CDBS Error: Attempting to delete hrs_row record(s) for delivered data'
      select h.delivery_number,h.reference_file_type,h.file_name,
             h.expansion_number,h.useafter_date,h.opus_flag,h.opus_load_date,
             h.archive_date,h.general_availability_date,h.reject_flag,
             h.reject_delivery_number,h.reject_by_file_name,
             h.reject_by_expansion_number
        from hrs_file h, deleted d
       where h.file_name = d.file_name
         and h.expansion_number = d.expansion_number
         and h.general_availability_date is not NULL
      print '*******************************************************************'
      print ' '

      /* rollback deleted hrs_row data */
      rollback transaction
      print 'NO RECORDS WERE DELETED'
      print ' '
      return
    end  /* hrs_file.general_availability_date is not null */
end  /* for delete row level data */

go
