create trigger hsp_file_insert
on hsp_file 
for insert as
begin
  declare @rel_info_type char(1)      /* relation_info.type, I(image) or T(table) */

  if (select count(*) from inserted) > 1
    begin  /* too many inserts */
      /* display error message */
      print '*******************************************************************'
      print 'CDBS Error: Attempting to insert more than 1 record into hsp_file '
      select delivery_number,reference_file_type,file_name,expansion_number,
        useafter_date,opus_flag,opus_load_date,archive_date,
        general_availability_date,reject_flag,reject_delivery_number,
        reject_by_file_name,reject_by_expansion_number from inserted
      print '*******************************************************************'
      print ' '

      rollback transaction
      print 'NO RECORDS WERE INSERTED'
      print ' '
      return
    end /* too many inserts */


  select @rel_info_type = r.type 
    from relation_info r, inserted i
   where r.reference_file_type = i.reference_file_type
     and r.instrument = 'HSP'

  /* Table record */
  if @rel_info_type = 'T'
    begin /* Table record */

      update hsp_file
         set hsp_file.reject_flag = 'Y',
             hsp_file.reject_delivery_number = inserted.delivery_number,
             hsp_file.reject_by_file_name = inserted.file_name,
             hsp_file.reject_by_expansion_number = inserted.expansion_number
        from hsp_file, inserted
       where hsp_file.reference_file_type = inserted.reference_file_type
         and hsp_file.useafter_date = inserted.useafter_date
         and hsp_file.reject_flag = 'N'
         and hsp_file.opus_flag = inserted.opus_flag
         and hsp_file.file_name != inserted.file_name 
             /* can never reject a file with same file name */
    end  /* Table record */


  /* Image record */
  if @rel_info_type = 'I'
    begin /* Image record */

      /* check existence of corresponding row level record */
      if not exists (select *
            from hsp_row, inserted
           where hsp_row.file_name = inserted.file_name
             and hsp_row.expansion_number = inserted.expansion_number) 
        begin  /* row level record not found */
         
          /* display error message */
          print '*******************************************************************'
          print 'CDBS Error: No row level record for hsp_file'
          select file_name, expansion_number from inserted
          print '*******************************************************************'
          print ' '

          /* row_level record not found, reject inserted file_level record */
          rollback transaction
          print 'NO RECORDS WERE INSERTED'
          print ' '
          return
        end /* row level record not found */


      /* set reject record */
      update hsp_file
         set hsp_file.reject_flag = 'Y',
             hsp_file.reject_delivery_number = i.delivery_number,
             hsp_file.reject_by_file_name = i.file_name,
             hsp_file.reject_by_expansion_number = i.expansion_number
        from hsp_file n, inserted i, hsp_row r1, hsp_row r2
       where n.reference_file_type = i.reference_file_type
         and n.useafter_date = i.useafter_date
         and n.opus_flag = i.opus_flag
         and n.reject_flag = 'N'
         and n.file_name != i.file_name
         and r1.file_name = i.file_name
         and r1.expansion_number = i.expansion_number
         and r1.aper_name = r2.aper_name
         and r1.det_num = r2.det_num
         and r1.type = r2.type
         and r1.voltage = r2.voltage
         and r1.vgaind = r2.vgaind
         and r1.thresh = r2.thresh
         and n.file_name = r2.file_name
         and n.expansion_number = r2.expansion_number
    end /* Image record */  

  /* insert record to table <opus_log> */
  insert opus_log (delivery_number, file_name, expansion_number, instrument,
      reference_file_type, operation) select delivery_number, file_name,
      expansion_number, 'HSP', reference_file_type, 'I'
      from inserted where opus_flag = 'Y' 

end  /* for insert */

go
