create trigger wfpc_file_update
on wfpc_file
for update as
begin

  declare @delivery_num int        /* opus_log.delivery_num */
  declare @opr_status   char(1)    /* opus_log.operation    */

  /* determine if we need to insert record to <opus_log> table */
  if exists (select * from inserted, deleted
      where inserted.opus_flag = 'Y' and inserted.reject_flag = 'Y'
        and deleted.reject_flag = 'N' and inserted.file_name = deleted.file_name
        and inserted.expansion_number = deleted.expansion_number) 
    begin /* if select count */
  
      if (select count(*) from inserted) > 1
        begin  /* too many inserts */
          /* display error message */
          print '*******************************************************************'
          print 'CDBS Error: Attempting to multi-reject in wfpc_file '
          select delivery_number,reference_file_type,file_name,expansion_number,
           useafter_date,opus_flag,opus_load_date,archive_date,
           general_availability_date,reject_flag,reject_delivery_number,
           reject_by_file_name,reject_by_expansion_number from inserted
          print '*******************************************************************'
          print ' '

          rollback transaction
          print 'NO RECORDS WERE INSERTED'
          print ' '
          return
        end /* too many inserts */

      /* use delivery_number.value as opus_log.delivery_num */
      select @delivery_num = value from delivery_number

      /* determine opus_log.operation value */
      if exists (select * from inserted, wfpc_file
          where inserted.file_name = wfpc_file.file_name
            and inserted.expansion_number != wfpc_file.expansion_number
            and wfpc_file.reject_flag = 'N') 
         select @opr_status = 'R'
      else
         select @opr_status = 'D'

      insert opus_log (delivery_number, file_name, expansion_number, instrument,
         reference_file_type, operation) select @delivery_num, file_name,
         expansion_number, 'WFPC', reference_file_type, @opr_status
         from inserted
    end  /* if select count  */



  if ( update (archive_date) and exists (select * from wfpc_file, inserted
                  where wfpc_file.file_name = inserted.file_name and
                  wfpc_file.expansion_number = inserted.expansion_number and
                  wfpc_file.opus_load_date is not null) )
        /* add file to be processed by bestref */
        insert into new_cal_files (instrument, file_name, expansion_number)
        select 'WFPC', file_name, expansion_number from inserted where
        opus_flag='Y'

  if ( update (opus_load_date) and exists (select * from wfpc_file, inserted
                  where wfpc_file.file_name = inserted.file_name and
                  wfpc_file.expansion_number = inserted.expansion_number and
                  wfpc_file.archive_date is not null ))
        /* add file to be processed by bestref */
        insert into new_cal_files (instrument, file_name, expansion_number)
        select 'WFPC', file_name, expansion_number from inserted where
        opus_flag='Y'

end  /* update */

go
