create trigger wfpc_row_delete
on wfpc_row
for delete as
begin /* for delete row level data */

  /* check corresponding file level table's general_availability_date */
  /* reject delete if general_availability_date is not null           */
  if exists (select * from wfpc_file w, deleted d
     where w.file_name = d.file_name and w.expansion_number = d.expansion_number 
       and general_availability_date is not NULL) 
    begin /* wfpc_file.general_availability_date is not null */

      /* display error message */
      print '*******************************************************************'
      print 'CDBS Error: Attempting to delete wfpc_row record(s) for delivered data'
      select w.delivery_number,w.reference_file_type,w.file_name,
             w.expansion_number,w.useafter_date,w.opus_flag,w.opus_load_date,
             w.archive_date,w.general_availability_date,w.reject_flag,
             w.reject_delivery_number,w.reject_by_file_name,
             w.reject_by_expansion_number
        from wfpc_file w, deleted d
       where w.file_name = d.file_name
         and w.expansion_number = d.expansion_number
         and w.general_availability_date is not NULL
      print '*******************************************************************'
      print ' '

      /* rollback deleted wfpc_row data */
      rollback transaction
      print 'NO RECORDS WERE DELETED'
      print ' '
      return
    end  /* wfpc_file.general_availability_date is not null */
end  /* for delete row level data */

go
