/*****************************************************************************/
/*                                                                           */
/*  File name :   acs_row.sql                                                */
/*                                                                           */
/*  Description : instrucment "acs" row level table                          */
/*                associated file level table : acs_file                     */
/*                                                                           */
/*  Note :        for any given delivery, row level data should be inserted  */
/*                to "acs_row" prior insert file level data to "acs_file"    */
/*                                                                           */
/*  Modification History:                                                    */
/*                                                                           */
/*    Date       OPR      Who                       Reason                   */
/*  --------   -------    ---   -------------------------------------------  */
/*  11/12/98               sk   Original                                     */
/*  02/22/99               sk   rename chip to ccdchip                       */
/*  09/06/00    42348      sk   add flashcur, shutrpos                       */
/*  09/21/01    44320      sk   add detchip,direction,wavelength             */
/*  11/20/01    44673      sk   add obstype                                  */
/*  04/15/02    45589      sk   add naxis1,naxis2,ltv1,ltv2                  */
/*  06/16/03    47292      mss  add fwoffset                             */
/*  07/16/08    60425      mss  replace fwoffset with fw[12s]offst       */
/*  09/15/08    60769      mss  change ccdgain from int to float         */
/*  05/04/11   xxxxx    mss/Gardner added IDENTITY field for unique MSSQL key */
/*****************************************************************************/
  
create table acs_row (
   file_name                   varchar(50) not null,
   expansion_number            int         not null,
   delivery_number             int         not null,

   /* observation_mode  */
   detector                    char(3)     not null,
   ccdchip                     int         not null,
   ccdamp                      char(4)     not null,
   ccdgain                     float       not null,
   filter1                     varchar(10) not null,
   filter2                     varchar(10) not null,
   flashcur                    char(4)     not null,
   shutrpos                    varchar(5)  not null,
   detchip                     int         not null,
   direction                   char(7)     not null,
   wavelength                  int         not null,
   obstype                     varchar(13) not null,
   naxis1                      int         not null,
   naxis2                      int         not null,
   ltv1                        float       not null,
   ltv2                        float       not null,
   fw1offst                    int         not null,
   fw2offst                    int         not null,
   fwsoffst                    int         not null,

   
   /* equivalence_class */
   equivalence_class_severe    int         not null,
   equivalence_class_moderate  int         not null,

   pedigree                    varchar(50) not null,
   observation_begin_date      datetime    null,
   observation_end_date        datetime    null,
   acs_row_id                  bigint IDENTITY(1,1) NOT NULL,
   comment                     text        null)
go

sp_bindefault cdbs_char_default, 'acs_row.detector'
go
sp_bindefault cdbs_int_default, 'acs_row.ccdchip'
go
sp_bindefault cdbs_char_default, 'acs_row.ccdamp'
go
sp_bindefault cdbs_float_default, 'acs_row.ccdgain'
go
sp_bindefault cdbs_char_default, 'acs_row.filter1'
go
sp_bindefault cdbs_char_default, 'acs_row.filter2'
go
sp_bindefault cdbs_char_default, 'acs_row.flashcur'
go
sp_bindefault cdbs_char_default, 'acs_row.shutrpos'
go
sp_bindefault cdbs_int_default, 'acs_row.detchip'
go
sp_bindefault cdbs_char_default, 'acs_row.direction'
go
sp_bindefault cdbs_int_default, 'acs_row.wavelength'
go
sp_bindefault cdbs_char_default, 'acs_row.obstype'
go
sp_bindefault cdbs_int_default, 'acs_row.naxis1'
go
sp_bindefault cdbs_int_default, 'acs_row.naxis2'
go
sp_bindefault cdbs_float_default, 'acs_row.ltv1'
go
sp_bindefault cdbs_float_default, 'acs_row.ltv2'
go
sp_bindefault cdbs_int_default, 'acs_row.fw1offst'
go
sp_bindefault cdbs_int_default, 'acs_row.fw2offst'
go
sp_bindefault cdbs_int_default, 'acs_row.fwsoffst'
go
