/*****************************************************************************/
/*                                                                           */
/*  File name :   cdbs_mode_data.sql                                         */
/*                                                                           */
/*  Related file : <instrument>_row.sql, file_extensions_data.sql,           */
/*                 opus_fields_data.sql, relation_info_data.sql              */
/*                                                                           */
/*  How to add record and set file_selection:                                */
/*  Based on Appendix B table:                                               */
/*     if ref_type='i', mode='+', add a record with file_selection='Y'       */
/*     if ref_type='t', mode=+/I/C/S, add a record with file_selection='N'   */
/*     if ref_type='t', mode='T', add a record with file_selection='Y'       */
/*                                                                           */
/*  Modification History:                                                    */
/*                                                                           */
/*    Date       OPR      Who                       Reason                   */
/*  --------   -------    ---   -------------------------------------------  */
/*  07/08/96               sk   Original                                     */
/*  04/09/97   33811       sk   Add stis reference_file_type "MOC"           */
/*  04/30/97   34029       sk   remove STIS/WCP/aperture entry               */
/*  05/16/97               sk   add foc.unitab modes                         */
/*  12/17/97   35926       sk   remove STIS/LMP/sclamp and lampset data      */
/*  12/17/97   35928       sk   add 5 new STIS/PCT data                      */
/*  03/05/98   36456       sk   add 4 new FOS/PCP data                       */
/*  11/12/98               sk   add ACS mode data                            */
/*  01/25/98               sk   delete CDK,MDK add DRK data from ACS         */
/*  02/12/99               sk   rename ACS chip to ccdchip                   */
/*  02/24/99   38259/60    sk   add stis reference_file_type "WCP"           */
/*  05/03/99   38960       sk   delete STIS/crsplit record                   */
/*  09/06/00   42348       sk   add ACS FLS data                             */
/*  09/25/00   42445       sk   add 7 STIS  reference_file_type:             */
/*                              "CDS","ECH","EXS","HAL","RIP","SRW","TEL"    */
/*  07/23/01   43737       sk   delete STIS/IDC/aperture/N data              */
/*  09/06/01   44381       sk   replace STIS/IDC opt_elem to filter          */
/*  09/21/01   44320       sk   add ACS IDC data                             */
/*  11/20/01   44673       sk   add ACS/PFL/obstype data                     */
/*  12/14/01   43974       sk   add FOS/CCSE/parmid data                     */
/*  03/04/02   45289       sk   add NIC/TDD/camera/Y data                    */
/*  04/12/02   45386       sk   add STIS/TDS/detector/Y data                 */
/*                              STIS/TDS/opt_elem and obstype/N data         */
/*  04/12/02   45569       sk   add STIS/TDC/detector/Y data                 */
/*  04/16/02   45589       sk   add ACS/BIA/naxis1,2,ltv1,2/Y data           */
/*  06/12/02   45993       mss  add SYNPHOT/THERMAL                          */
/*  09/02/02   46235       mss  add WFC3                                     */
/*  10/01/02   46595       sk   delete ACS/IDC/wavelength                    */
/*                              add ACS/IDC/filter1,2/Y                      */
/*  01/28/03   47142       sk   change ACS/IDC/filter1,2/N                   */
/*  06/16/03   47292       mss  add ACS/PFL/fwoffset                         */
/*  09/16/03   49436       mss  add COS                                      */
/*  11/03/03   38260       mss  add back in missing STIS/PHT                 */
/*  03/31/04   50488       mss  remove TDS/obstype (no longer needed)        */
/*  07/01/04   51056       sk   add ACS/MDZ                                  */
/*  07/01/04   51066       sk   add ACS/DXY                                  */
/*  10/12/04   51981       mss  add ACS/CFL,CSP                              */
/*  10/18/04   51962       mss  add NIC/IDC                                  */
/*  08/31/05   53525       mss  add STIS/GAC                                 */
/*  09/15/06   56377       mss  add NIC/SDK                                  */
/*  05/09/07   57574       mss  add WFC3/DRK/subtype                         */
/*  05/22/07   57609       mss  add NIC/NLC                                  */
/*  07/03/07   57851       mss  add WFPC2/W4T                                */
/*  07/23/07   58375       mss  add COS/BURST                                */
/*  02/28/08   55604       mss  add NIC/SCN,PSB                              */
/*  05/15/08   60017       mss  adjust ACS/DXY to include OBSTYPE            */
/*  05/28/08   59404       mss  add WFC3/MDZ                                 */
/*  07/02/08   60329       mss  remove COS/FLAT/obstype                      */
/*  07/16/08   60425       mss  replace ACS/FWOFFSET with FW[12S]OFFST       */
/*  08/14/08   60643       mss  add WFPC2/DXY                                */
/*  09/18/08   60848       mss  add NIC/PMD,PMK                              */
/*  11/07/08   xxxxx       mss  add NIC/TDF                                  */
/*  02/02/09   58375       mss  add COS/TDS                                  */
/*  02/27/09   62082       mss  change WFC3/BIA to include aperture          */
/*  07/23/09   63148       mss  add NIC/DRK/obsmode                          */
/*  10/20/09   63765       mss  add COS/FLAT/opt_elem                        */
/*  12/22/09   64177       mss  adjust WFC3 IDC                              */
/*  10/07/10   66259       mss  add COS/SPWCS                                */
/*  10/13/10   xxxxx       mss  add COS/PHA/opt_elem                         */
/*  05/12/11   68310       mss  add ACS/CTE/DKC                              */
/*  06/27/11   68306       mss  add ACS/IMP                                  */
/*  08/26/11   68293       mss  add COS/WALK                                 */
/*  09/01/11   69084       mss  add ACS/D2I,NPL                              */
/*  10/14/11   69530       mss  add WFC3/BIA CHINJECT                        */
/*                                                                           */
/*****************************************************************************/

/* cdbs_mode data */
truncate table cdbs_mode
go

/* instrument, reference_file_type, modes, file_select */

insert into cdbs_mode values ('FOC', 'BAC', 'optcrly', 'Y')
go
insert into cdbs_mode values ('FOC', 'BAC', 'pxformt', 'Y')
go
insert into cdbs_mode values ('FOC', 'ITF', 'optcrly', 'Y')
go
insert into cdbs_mode values ('FOC', 'ITF', 'pxformt', 'Y')
go
insert into cdbs_mode values ('FOC', 'ITF', 'sampoff', 'Y')
go
insert into cdbs_mode values ('FOC', 'ITF', 'samppln', 'Y')
go
insert into cdbs_mode values ('FOC', 'ITF', 'lineoff', 'Y')
go
insert into cdbs_mode values ('FOC', 'ITF', 'linepfm', 'Y')
go
insert into cdbs_mode values ('FOC', 'SDE', 'pxformt', 'Y')
go
insert into cdbs_mode values ('FOC', 'SDE', 'optelt1', 'Y')
go
insert into cdbs_mode values ('FOC', 'SDE', 'optelt2', 'Y')
go
insert into cdbs_mode values ('FOC', 'GEO', 'optcrly', 'Y')
go
insert into cdbs_mode values ('FOC', 'GEO', 'pxformt', 'Y')
go
insert into cdbs_mode values ('FOC', 'GEO', 'optelt1', 'Y')
go
insert into cdbs_mode values ('FOC', 'GEO', 'optelt2', 'Y')
go
insert into cdbs_mode values ('FOC', 'GEO', 'sampoff', 'Y')
go
insert into cdbs_mode values ('FOC', 'GEO', 'samppln', 'Y')
go
insert into cdbs_mode values ('FOC', 'GEO', 'lineoff', 'Y')
go
insert into cdbs_mode values ('FOC', 'GEO', 'linepfm', 'Y')
go
insert into cdbs_mode values ('FOC', 'GEO', 'cammode', 'Y')
go
insert into cdbs_mode values ('FOC', 'GEO', 'smmmode', 'Y')
go
insert into cdbs_mode values ('FOC', 'BLM', 'optcrly', 'Y')
go
insert into cdbs_mode values ('FOC', 'BLM', 'pxformt', 'Y')
go
insert into cdbs_mode values ('FOC', 'UNI', 'optcrly', 'Y')
go
insert into cdbs_mode values ('FOC', 'UNI', 'cammode', 'Y')
go
insert into cdbs_mode values ('FOC', 'UNI', 'wavelength', 'Y')
go
insert into cdbs_mode values ('FOC', 'UNITAB', 'optcrly', 'N')
go
insert into cdbs_mode values ('FOC', 'UNITAB', 'cammode', 'N')
go
insert into cdbs_mode values ('FOC', 'UNITAB', 'wavelength', 'N')
go
insert into cdbs_mode values ('FOC', 'UNITAB', 'uni_file_name', 'N')
go

insert into cdbs_mode values ('HSP', 'CCP0', 'aper_name', 'N')
go
insert into cdbs_mode values ('HSP', 'CCP1', 'det_num', 'N')
go
insert into cdbs_mode values ('HSP', 'CCP1', 'type', 'N')
go
insert into cdbs_mode values ('HSP', 'CCP1', 'voltage', 'N')
go
insert into cdbs_mode values ('HSP', 'CCP2', 'det_num', 'N')
go
insert into cdbs_mode values ('HSP', 'CCP2', 'vgaind', 'N')
go
insert into cdbs_mode values ('HSP', 'CCP3', 'det_num', 'N')
go
insert into cdbs_mode values ('HSP', 'CCP3', 'type', 'N')
go
insert into cdbs_mode values ('HSP', 'CCP4', 'aper_name', 'N')
go
insert into cdbs_mode values ('HSP', 'CCP4', 'det_num', 'N')
go
insert into cdbs_mode values ('HSP', 'CCP7', 'det_num', 'N')
go
insert into cdbs_mode values ('HSP', 'CCP7', 'vgaind', 'N')
go
insert into cdbs_mode values ('HSP', 'CCP8', 'det_num', 'N')
go
insert into cdbs_mode values ('HSP', 'CCP8', 'voltage', 'N')
go
insert into cdbs_mode values ('HSP', 'CCP8', 'thresh', 'N')
go
insert into cdbs_mode values ('HSP', 'CCP9', 'aper_name', 'N')
go
insert into cdbs_mode values ('HSP', 'CCP9', 'det_num', 'N')
go

insert into cdbs_mode values ('FOS', 'AIS', 'detector', 'Y')
go
insert into cdbs_mode values ('FOS', 'AIS', 'overscan', 'Y')
go
insert into cdbs_mode values ('FOS', 'AIS', 'polar_id', 'Y')
go
insert into cdbs_mode values ('FOS', 'AIS', 'fgwa_id', 'Y')
go
insert into cdbs_mode values ('FOS', 'AIS', 'pass_dir', 'Y')
go
insert into cdbs_mode values ('FOS', 'BAC', 'detector', 'Y')
go
insert into cdbs_mode values ('FOS', 'BAC', 'overscan', 'Y')
go
insert into cdbs_mode values ('FOS', 'FLT', 'detector', 'Y')
go
insert into cdbs_mode values ('FOS', 'FLT', 'overscan', 'Y')
go
insert into cdbs_mode values ('FOS', 'FLT', 'aper_id', 'Y')
go
insert into cdbs_mode values ('FOS', 'FLT', 'aper_pos', 'Y')
go
insert into cdbs_mode values ('FOS', 'FLT', 'polar_id', 'Y')
go
insert into cdbs_mode values ('FOS', 'FLT', 'fgwa_id', 'Y')
go
insert into cdbs_mode values ('FOS', 'FLT', 'pass_dir', 'Y')
go
insert into cdbs_mode values ('FOS', 'IVS', 'detector', 'Y')
go
insert into cdbs_mode values ('FOS', 'IVS', 'overscan', 'Y')
go
insert into cdbs_mode values ('FOS', 'IVS', 'aper_id', 'Y')
go
insert into cdbs_mode values ('FOS', 'IVS', 'aper_pos', 'Y')
go
insert into cdbs_mode values ('FOS', 'IVS', 'polar_id', 'Y')
go
insert into cdbs_mode values ('FOS', 'IVS', 'fgwa_id', 'Y')
go
insert into cdbs_mode values ('FOS', 'IVS', 'pass_dir', 'Y')
go
insert into cdbs_mode values ('FOS', 'RET', 'detector', 'Y')
go
insert into cdbs_mode values ('FOS', 'RET', 'overscan', 'Y')
go
insert into cdbs_mode values ('FOS', 'RET', 'polar_id', 'Y')
go
insert into cdbs_mode values ('FOS', 'RET', 'fgwa_id', 'Y')
go
insert into cdbs_mode values ('FOS', 'DDT', 'detector', 'Y')
go
insert into cdbs_mode values ('FOS', 'QIN', 'detector', 'Y')
go
insert into cdbs_mode values ('FOS', 'QIN', 'overscan', 'Y')
go
insert into cdbs_mode values ('FOS', 'QIN', 'aper_id', 'Y')
go
insert into cdbs_mode values ('FOS', 'QIN', 'aper_pos', 'Y')
go
insert into cdbs_mode values ('FOS', 'QIN', 'polar_id', 'Y')
go
insert into cdbs_mode values ('FOS', 'QIN', 'fgwa_id', 'Y')
go
insert into cdbs_mode values ('FOS', 'QIN', 'pass_dir', 'Y')
go
insert into cdbs_mode values ('FOS', 'PCP', 'detector', 'Y')
go
insert into cdbs_mode values ('FOS', 'PCP', 'aper_id', 'Y')
go
insert into cdbs_mode values ('FOS', 'PCP', 'polar_id', 'Y')
go
insert into cdbs_mode values ('FOS', 'PCP', 'fgwa_id', 'Y')
go
insert into cdbs_mode values ('FOS', 'LSF', 'detector', 'Y')
go
insert into cdbs_mode values ('FOS', 'LSF', 'aper_id', 'Y')
go
insert into cdbs_mode values ('FOS', 'LSF', 'wavelength', 'Y')
go
insert into cdbs_mode values ('FOS', 'PSF', 'detector', 'Y')
go
insert into cdbs_mode values ('FOS', 'PSF', 'wavelength', 'Y')
go
insert into cdbs_mode values ('FOS', 'CCS0', 'detector', 'N')
go
insert into cdbs_mode values ('FOS', 'CCS0', 'aper_id', 'N')
go
insert into cdbs_mode values ('FOS', 'CCS0', 'aper_pos', 'N')
go
insert into cdbs_mode values ('FOS', 'CCS1', 'detector', 'N')
go
insert into cdbs_mode values ('FOS', 'CCS1', 'fgwa_id', 'N')
go
insert into cdbs_mode values ('FOS', 'CCS2', 'detector', 'N')
go
insert into cdbs_mode values ('FOS', 'CCS2', 'fgwa_id', 'N')
go
insert into cdbs_mode values ('FOS', 'CCS2', 'fchnl', 'N')
go
insert into cdbs_mode values ('FOS', 'CCS2', 'nxsteps', 'N')
go
insert into cdbs_mode values ('FOS', 'CCS3', 'detector', 'N')
go
insert into cdbs_mode values ('FOS', 'CCS4', 'detector', 'N')
go
insert into cdbs_mode values ('FOS', 'CCS4', 'polar_id', 'N')
go
insert into cdbs_mode values ('FOS', 'CCS4', 'fgwa_id', 'N')
go
insert into cdbs_mode values ('FOS', 'CCS5', 'detector', 'N')
go
insert into cdbs_mode values ('FOS', 'CCS5', 'aper_id', 'N')
go
insert into cdbs_mode values ('FOS', 'CCS5', 'fgwa_id', 'N')
go
insert into cdbs_mode values ('FOS', 'CCS5', 'nxsteps', 'N')
go
insert into cdbs_mode values ('FOS', 'CCS6', 'detector', 'N')
go
insert into cdbs_mode values ('FOS', 'CCS6', 'aper_id', 'N')
go
insert into cdbs_mode values ('FOS', 'CCS6', 'aper_pos', 'N')
go
insert into cdbs_mode values ('FOS', 'CCS6', 'polar_id', 'N')
go
insert into cdbs_mode values ('FOS', 'CCS6', 'fgwa_id', 'N')
go
insert into cdbs_mode values ('FOS', 'CCS6', 'pass_dir', 'N')
go
insert into cdbs_mode values ('FOS', 'CCS7', 'detector', 'N')
go
insert into cdbs_mode values ('FOS', 'CCS8', 'detector', 'N')
go
insert into cdbs_mode values ('FOS', 'CCS9', 'detector', 'N')
go
insert into cdbs_mode values ('FOS', 'CCS9', 'fgwa_id', 'N')
go
insert into cdbs_mode values ('FOS', 'CCSB', 'detector', 'N')
go
insert into cdbs_mode values ('FOS', 'CCSB', 'aper_id', 'N')
go
insert into cdbs_mode values ('FOS', 'CCSB', 'fgwa_id', 'N')
go
insert into cdbs_mode values ('FOS', 'CCSC', 'detector', 'N')
go
insert into cdbs_mode values ('FOS', 'CCSC', 'aper_id', 'N') 
go
insert into cdbs_mode values ('FOS', 'CCSD', 'detector', 'N')
go
insert into cdbs_mode values ('FOS', 'CCSD', 'fgwa_id', 'N')
go
insert into cdbs_mode values ('FOS', 'CCG2', 'detector', 'N')
go
insert into cdbs_mode values ('FOS', 'CCSE', 'parmid', 'Y')
go


insert into cdbs_mode values ('HRS', 'DIO', 'detector', 'Y')
go
insert into cdbs_mode values ('HRS', 'PHC', 'grating', 'Y')
go
insert into cdbs_mode values ('HRS', 'VIG', 'grating', 'Y')
go
insert into cdbs_mode values ('HRS', 'ABS', 'grating', 'Y')
go
insert into cdbs_mode values ('HRS', 'NET', 'grating', 'Y')
go
insert into cdbs_mode values ('HRS', 'QIN', 'detector', 'Y')
go
insert into cdbs_mode values ('HRS', 'WAVECAL', 'targetid', 'N')
go
insert into cdbs_mode values ('HRS', 'CCR1', 'detector', 'N')
go
insert into cdbs_mode values ('HRS', 'CCR2', 'detector', 'N')
go
insert into cdbs_mode values ('HRS', 'CCR3', 'detector', 'N')
go
insert into cdbs_mode values ('HRS', 'CCR4', 'grating', 'N')
go
insert into cdbs_mode values ('HRS', 'CCR5', 'grating', 'N')
go
insert into cdbs_mode values ('HRS', 'CCR6', 'grating', 'N')
go
insert into cdbs_mode values ('HRS', 'CCR7', 'grating', 'N')
go
insert into cdbs_mode values ('HRS', 'CCR8', 'grating', 'N')
go
insert into cdbs_mode values ('HRS', 'CCR8', 'aperture', 'N')
go
insert into cdbs_mode values ('HRS', 'CCR8', 'sporder', 'N')
go
insert into cdbs_mode values ('HRS', 'CCR9', 'grating', 'N')
go
insert into cdbs_mode values ('HRS', 'CCR9', 'sporder', 'N')
go
insert into cdbs_mode values ('HRS', 'CCRA', 'grating', 'N')
go
insert into cdbs_mode values ('HRS', 'CCRB', 'grating', 'N')
go
insert into cdbs_mode values ('HRS', 'CCRB', 'aperture', 'N')
go
insert into cdbs_mode values ('HRS', 'CCRB', 'sporder', 'N')
go
insert into cdbs_mode values ('HRS', 'CCRC', 'grating', 'N')
go
insert into cdbs_mode values ('HRS', 'CCRD', 'detector', 'N')
go
insert into cdbs_mode values ('HRS', 'CCG2', 'detector', 'N')
go

insert into cdbs_mode values ('WFPC2', 'MSK', 'mode', 'Y')
go
insert into cdbs_mode values ('WFPC2', 'A2D', 'mode', 'Y')
go
insert into cdbs_mode values ('WFPC2', 'A2D', 'atodgain', 'Y')
go
insert into cdbs_mode values ('WFPC2', 'BAS', 'mode', 'Y')
go
insert into cdbs_mode values ('WFPC2', 'BAS', 'atodgain', 'Y')
go
insert into cdbs_mode values ('WFPC2', 'DRK', 'mode', 'Y')
go
insert into cdbs_mode values ('WFPC2', 'DRK', 'atodgain', 'Y')
go
insert into cdbs_mode values ('WFPC2', 'DRK', 'serials', 'Y')
go
insert into cdbs_mode values ('WFPC2', 'FLT', 'mode', 'Y')
go
insert into cdbs_mode values ('WFPC2', 'FLT', 'filter1', 'Y')
go
insert into cdbs_mode values ('WFPC2', 'FLT', 'filter2', 'Y')
go
insert into cdbs_mode values ('WFPC2', 'SHD', 'mode', 'Y')
go
insert into cdbs_mode values ('WFPC2', 'SHD', 'shutter', 'Y')
go
insert into cdbs_mode values ('WFPC2', 'W4T', 'atodgain', 'Y')
go
insert into cdbs_mode values ('WFPC2', 'IDC', 'mode', 'N')
go
insert into cdbs_mode values ('WFPC2', 'OFF', 'mode', 'N')
go
insert into cdbs_mode values ('WFPC2', 'DXY', 'mode', 'Y')
go

insert into cdbs_mode values ('WFPC', 'A2D', 'camera', 'Y')
go
insert into cdbs_mode values ('WFPC', 'A2D', 'mode', 'Y')
go
insert into cdbs_mode values ('WFPC', 'BAS', 'camera', 'Y')
go
insert into cdbs_mode values ('WFPC', 'BAS', 'mode', 'Y')
go
insert into cdbs_mode values ('WFPC', 'DRK', 'camera', 'Y')
go
insert into cdbs_mode values ('WFPC', 'DRK', 'mode', 'Y')
go
insert into cdbs_mode values ('WFPC', 'DRK', 'clock', 'Y')
go
insert into cdbs_mode values ('WFPC', 'FLT', 'camera', 'Y')
go
insert into cdbs_mode values ('WFPC', 'FLT', 'mode', 'Y')
go
insert into cdbs_mode values ('WFPC', 'FLT', 'filter1', 'Y')
go
insert into cdbs_mode values ('WFPC', 'FLT', 'filter2', 'Y')
go
insert into cdbs_mode values ('WFPC', 'DFLT', 'camera', 'Y')
go
insert into cdbs_mode values ('WFPC', 'DFLT', 'mode', 'Y')
go
insert into cdbs_mode values ('WFPC', 'DFLT', 'filter1', 'Y')
go
insert into cdbs_mode values ('WFPC', 'DFLT', 'filter2', 'Y')
go
insert into cdbs_mode values ('WFPC', 'DFLT', 'filtnam1', 'Y')
go
insert into cdbs_mode values ('WFPC', 'DFLT', 'filtnam2', 'Y')
go
insert into cdbs_mode values ('WFPC', 'MSK', 'camera', 'Y')
go
insert into cdbs_mode values ('WFPC', 'MSK', 'mode', 'Y')
go
insert into cdbs_mode values ('WFPC', 'PRF', 'camera', 'Y')
go
insert into cdbs_mode values ('WFPC', 'PRF', 'mode', 'Y')
go
insert into cdbs_mode values ('WFPC', 'PRF', 'shutter', 'Y')
go
insert into cdbs_mode values ('WFPC', 'PSF', 'camera', 'Y')
go
insert into cdbs_mode values ('WFPC', 'PSF', 'mode', 'Y')
go
insert into cdbs_mode values ('WFPC', 'PSF', 'filtnam1', 'Y')
go
insert into cdbs_mode values ('WFPC', 'PSF', 'filtnam2', 'Y')
go
insert into cdbs_mode values ('WFPC', 'PUR', 'camera', 'Y')
go
insert into cdbs_mode values ('WFPC', 'PUR', 'mode', 'Y')
go
insert into cdbs_mode values ('WFPC', 'PHOTTAB', 'photmode', 'N')
go

insert into cdbs_mode values ('STIS', 'BIA', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', 'BIA', 'ccdamp', 'Y')
go
insert into cdbs_mode values ('STIS', 'BIA', 'ccdgain', 'Y')
go
insert into cdbs_mode values ('STIS', 'BIA', 'ccdoffst', 'Y')
go
insert into cdbs_mode values ('STIS', 'BIA', 'binaxis1', 'Y')
go
insert into cdbs_mode values ('STIS', 'BIA', 'binaxis2', 'Y')
go
insert into cdbs_mode values ('STIS', 'DRK', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', 'DRK', 'ccdamp', 'Y')
go
insert into cdbs_mode values ('STIS', 'DRK', 'ccdgain', 'Y')
go
insert into cdbs_mode values ('STIS', 'SSC', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', 'PFL', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', 'PFL', 'opt_elem', 'Y')
go
insert into cdbs_mode values ('STIS', 'PFL', 'obstype', 'Y')
go
insert into cdbs_mode values ('STIS', 'PFL', 'aperture', 'Y')
go
insert into cdbs_mode values ('STIS', 'PFL', 'cenwave', 'Y')
go
insert into cdbs_mode values ('STIS', 'DFL', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', 'LFL', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', 'LFL', 'opt_elem', 'Y')
go
insert into cdbs_mode values ('STIS', 'LFL', 'obstype', 'Y')
go
insert into cdbs_mode values ('STIS', 'LFL', 'aperture', 'Y')
go
insert into cdbs_mode values ('STIS', 'LFL', 'cenwave', 'Y')
go
insert into cdbs_mode values ('STIS', 'SSD', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', 'CCD', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', 'CCD', 'ccdamp', 'N')
go
insert into cdbs_mode values ('STIS', 'CCD', 'ccdgain', 'N')
go
insert into cdbs_mode values ('STIS', 'CCD', 'ccdoffst', 'N')
go
insert into cdbs_mode values ('STIS', 'CCD', 'binaxis1', 'N')
go
insert into cdbs_mode values ('STIS', 'CCD', 'binaxis2', 'N')
go
insert into cdbs_mode values ('STIS', 'A2D', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', 'A2D', 'ccdamp', 'N')
go
insert into cdbs_mode values ('STIS', 'A2D', 'ccdgain', 'N')
go
insert into cdbs_mode values ('STIS', 'CRR', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', 'BPX', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', 'LIN', 'detector', 'N')
go
insert into cdbs_mode values ('STIS', 'PHT', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', 'PHT', 'opt_elem', 'N')
go
insert into cdbs_mode values ('STIS', 'PHT', 'obstype', 'Y')
go
insert into cdbs_mode values ('STIS', 'PHT', 'cenwave', 'N')
go
insert into cdbs_mode values ('STIS', 'WCP', 'detector', 'N')
go
insert into cdbs_mode values ('STIS', 'WCP', 'opt_elem', 'N')
go
insert into cdbs_mode values ('STIS', 'WCP', 'obstype', 'Y')
go
insert into cdbs_mode values ('STIS', 'WCP', 'cenwave', 'N')
go
insert into cdbs_mode values ('STIS', 'APT', 'aperture', 'N')
go
insert into cdbs_mode values ('STIS', 'APD', 'aperture', 'N')
go
insert into cdbs_mode values ('STIS', 'IDC', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', 'IDC', 'filter',   'N')
go
insert into cdbs_mode values ('STIS', 'SDC', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', 'SDC', 'opt_elem', 'N')
go
insert into cdbs_mode values ('STIS', 'SDC', 'cenwave', 'N')
go
insert into cdbs_mode values ('STIS', 'IAC', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', 'IAC', 'opt_elem', 'N')
go
insert into cdbs_mode values ('STIS', 'IAC', 'cenwave', 'N')
go
insert into cdbs_mode values ('STIS', 'DSP', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', 'DSP', 'opt_elem', 'N')
go
insert into cdbs_mode values ('STIS', 'DSP', 'cenwave', 'N')
go
insert into cdbs_mode values ('STIS', '1DT', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', '1DT', 'opt_elem', 'N')
go
insert into cdbs_mode values ('STIS', '1DT', 'cenwave', 'N')
go
insert into cdbs_mode values ('STIS', '1DX', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', '1DX', 'opt_elem', 'N')
go
insert into cdbs_mode values ('STIS', '1DX', 'aperture', 'N')
go
insert into cdbs_mode values ('STIS', '1DX', 'cenwave', 'N')
go
insert into cdbs_mode values ('STIS', 'MOC', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', 'MOC', 'opt_elem', 'N')
go
insert into cdbs_mode values ('STIS', 'MOC', 'cenwave', 'N')
go
insert into cdbs_mode values ('STIS', 'PCT', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', 'PCT', 'opt_elem', 'Y')
go
insert into cdbs_mode values ('STIS', 'PCT', 'obstype', 'Y')
go
insert into cdbs_mode values ('STIS', 'PCT', 'aperture', 'N')
go
insert into cdbs_mode values ('STIS', 'PCT', 'cenwave', 'N')
go
insert into cdbs_mode values ('STIS', 'CDS', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', 'CDS', 'opt_elem', 'N')
go
insert into cdbs_mode values ('STIS', 'ECH', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', 'ECH', 'opt_elem', 'N')
go
insert into cdbs_mode values ('STIS', 'EXS', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', 'EXS', 'opt_elem', 'N')
go
insert into cdbs_mode values ('STIS', 'HAL', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', 'HAL', 'opt_elem', 'N')
go
insert into cdbs_mode values ('STIS', 'RIP', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', 'RIP', 'opt_elem', 'N')
go
insert into cdbs_mode values ('STIS', 'RIP', 'cenwave', 'N')
go
insert into cdbs_mode values ('STIS', 'SRW', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', 'SRW', 'opt_elem', 'N')
go
insert into cdbs_mode values ('STIS', 'SRW', 'cenwave', 'N')
go
insert into cdbs_mode values ('STIS', 'TEL', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', 'TDS', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', 'TDS', 'opt_elem', 'N')
go
insert into cdbs_mode values ('STIS', 'TDC', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', 'GAC', 'detector', 'Y')
go
insert into cdbs_mode values ('STIS', 'GAC', 'opt_elem', 'N')
go
insert into cdbs_mode values ('STIS', 'GAC', 'aperture', 'N')
go
insert into cdbs_mode values ('STIS', 'GAC', 'cenwave', 'N')
go

insert into cdbs_mode values ('NIC', 'MSK', 'camera', 'Y')
go
insert into cdbs_mode values ('NIC', 'NOI', 'camera', 'Y')
go
insert into cdbs_mode values ('NIC', 'NOI', 'readout', 'Y')
go
insert into cdbs_mode values ('NIC', 'NOI', 'nread', 'Y')
go
insert into cdbs_mode values ('NIC', 'LIN', 'camera', 'Y')
go
insert into cdbs_mode values ('NIC', 'DRK', 'camera', 'Y')
go
insert into cdbs_mode values ('NIC', 'DRK', 'readout', 'Y')
go
insert into cdbs_mode values ('NIC', 'DRK', 'nread', 'Y')
go
insert into cdbs_mode values ('NIC', 'DRK', 'samp_seq', 'Y')
go
insert into cdbs_mode values ('NIC', 'DRK', 'obsmode', 'Y')
go
insert into cdbs_mode values ('NIC', 'FLT', 'camera', 'Y')
go
insert into cdbs_mode values ('NIC', 'FLT', 'filter', 'Y')
go
insert into cdbs_mode values ('NIC', 'ILM', 'camera', 'Y')
go
insert into cdbs_mode values ('NIC', 'ILM', 'filter', 'Y')
go
insert into cdbs_mode values ('NIC', 'TDD', 'camera', 'Y')
go
insert into cdbs_mode values ('NIC', 'BKG', 'camera', 'N')
go
insert into cdbs_mode values ('NIC', 'BKG', 'filter', 'N')
go
insert into cdbs_mode values ('NIC', 'IDC', 'camera', 'Y')
go
insert into cdbs_mode values ('NIC', 'SDK', 'camera', 'Y')
go
insert into cdbs_mode values ('NIC', 'NLC', 'camera', 'Y')
go
insert into cdbs_mode values ('NIC', 'PSB', 'camera', 'N')
go
insert into cdbs_mode values ('NIC', 'SCN', 'camera', 'N')
go
insert into cdbs_mode values ('NIC', 'ZPR', 'camera', 'N')
go
insert into cdbs_mode values ('NIC', 'PMD', 'camera', 'Y')
go
insert into cdbs_mode values ('NIC', 'PMK', 'camera', 'Y')
go
insert into cdbs_mode values ('NIC', 'TDF', 'camera', 'Y')
go
insert into cdbs_mode values ('NIC', 'TDF', 'filter', 'Y')
go

insert into cdbs_mode values ('MULTI', 'PHOFLDS', 'fld_name', 'N')
go
insert into cdbs_mode values ('MULTI', 'SPECOBS', 'targetid', 'N')
go
insert into cdbs_mode values ('MULTI', 'SPECOBS', 'obsmode', 'N')
go
insert into cdbs_mode values ('MULTI', 'SPECTRUM', 'targetid', 'N')
go
insert into cdbs_mode values ('SYNPHOT', 'THROUGHPUT', 'compname', 'N')
go
insert into cdbs_mode values ('SYNPHOT', 'THERMAL', 'compname', 'N')
go

insert into cdbs_mode values ('ACS', 'A2D', 'detector', 'Y')
go
insert into cdbs_mode values ('ACS', 'A2D', 'ccdchip', 'N')
go
insert into cdbs_mode values ('ACS', 'A2D', 'ccdamp', 'N')
go
insert into cdbs_mode values ('ACS', 'A2D', 'ccdgain', 'N')
go
insert into cdbs_mode values ('ACS', 'BIA', 'detector', 'Y')
go
insert into cdbs_mode values ('ACS', 'BIA', 'ccdamp', 'Y')
go
insert into cdbs_mode values ('ACS', 'BIA', 'ccdgain', 'Y')
go
insert into cdbs_mode values ('ACS', 'BIA', 'naxis1', 'Y')
go
insert into cdbs_mode values ('ACS', 'BIA', 'naxis2', 'Y')
go
insert into cdbs_mode values ('ACS', 'BIA', 'ltv1', 'Y')
go
insert into cdbs_mode values ('ACS', 'BIA', 'ltv2', 'Y')
go
insert into cdbs_mode values ('ACS', 'BPX', 'detector', 'Y')
go
insert into cdbs_mode values ('ACS', 'BPX', 'ccdchip', 'N')
go
insert into cdbs_mode values ('ACS', 'BPX', 'ccdamp', 'N')
go
insert into cdbs_mode values ('ACS', 'BPX', 'ccdgain', 'N')
go
insert into cdbs_mode values ('ACS', 'CCD', 'detector', 'Y')
go
insert into cdbs_mode values ('ACS', 'CCD', 'ccdchip', 'N')
go
insert into cdbs_mode values ('ACS', 'CCD', 'ccdamp', 'N')
go
insert into cdbs_mode values ('ACS', 'CCD', 'ccdgain', 'N')
go
insert into cdbs_mode values ('ACS', 'CFL', 'detector', 'Y')
go
insert into cdbs_mode values ('ACS', 'CFL', 'filter1', 'Y')
go
insert into cdbs_mode values ('ACS', 'CFL', 'filter2', 'Y')
go
insert into cdbs_mode values ('ACS', 'CFL', 'obstype', 'Y')
go
insert into cdbs_mode values ('ACS', 'CRR', 'detector', 'Y')
go
insert into cdbs_mode values ('ACS', 'CRR', 'ccdchip', 'N')
go
insert into cdbs_mode values ('ACS', 'CSP', 'detector', 'Y')
go
insert into cdbs_mode values ('ACS', 'CSP', 'obstype', 'Y')
go
insert into cdbs_mode values ('ACS', 'CTE', 'detector', 'Y')
go
insert into cdbs_mode values ('ACS', 'D2I', 'detector', 'Y')
go
insert into cdbs_mode values ('ACS', 'DFL', 'detector', 'Y')
go
insert into cdbs_mode values ('ACS', 'DKC', 'detector', 'Y')
go
insert into cdbs_mode values ('ACS', 'DKC', 'ccdamp', 'Y')
go
insert into cdbs_mode values ('ACS', 'DKC', 'ccdgain', 'Y')
go
insert into cdbs_mode values ('ACS', 'DRK', 'detector', 'Y')
go
insert into cdbs_mode values ('ACS', 'DRK', 'ccdamp', 'Y')
go
insert into cdbs_mode values ('ACS', 'DRK', 'ccdgain', 'Y')
go
insert into cdbs_mode values ('ACS', 'DXY', 'detector', 'Y')
go
insert into cdbs_mode values ('ACS', 'DXY', 'filter1', 'Y')
go
insert into cdbs_mode values ('ACS', 'DXY', 'filter2', 'Y')
go
insert into cdbs_mode values ('ACS', 'DXY', 'obstype', 'N')
go
insert into cdbs_mode values ('ACS', 'FLS', 'detector', 'Y')
go
insert into cdbs_mode values ('ACS', 'FLS', 'ccdamp', 'Y')
go
insert into cdbs_mode values ('ACS', 'FLS', 'ccdgain', 'Y')
go
insert into cdbs_mode values ('ACS', 'FLS', 'flashcur', 'Y')
go
insert into cdbs_mode values ('ACS', 'FLS', 'shutrpos', 'Y')
go
insert into cdbs_mode values ('ACS', 'IDC', 'detector', 'Y')
go
insert into cdbs_mode values ('ACS', 'IDC', 'filter1', 'N')
go
insert into cdbs_mode values ('ACS', 'IDC', 'filter2', 'N')
go
insert into cdbs_mode values ('ACS', 'IDC', 'detchip', 'N')
go
insert into cdbs_mode values ('ACS', 'IDC', 'direction', 'N')
go
insert into cdbs_mode values ('ACS', 'IMP', 'detector', 'Y')
go
insert into cdbs_mode values ('ACS', 'LFL', 'ccdamp', 'Y')
go
insert into cdbs_mode values ('ACS', 'LFL', 'ccdgain', 'Y')
go
insert into cdbs_mode values ('ACS', 'LFL', 'filter1', 'N')
go
insert into cdbs_mode values ('ACS', 'LFL', 'filter2', 'N')
go
insert into cdbs_mode values ('ACS', 'LIN', 'detector', 'Y')
go
insert into cdbs_mode values ('ACS', 'MDZ', 'detector', 'Y')
go
insert into cdbs_mode values ('ACS', 'NPL', 'detector', 'Y')
go
insert into cdbs_mode values ('ACS', 'NPL', 'filter1', 'Y')
go
insert into cdbs_mode values ('ACS', 'NPL', 'filter2', 'Y')
go
insert into cdbs_mode values ('ACS', 'NPL', 'obstype', 'N')
go
insert into cdbs_mode values ('ACS', 'OSC', 'detector', 'Y')
go
insert into cdbs_mode values ('ACS', 'OSC', 'ccdchip', 'N')
go
insert into cdbs_mode values ('ACS', 'OSC', 'ccdamp', 'N')
go
insert into cdbs_mode values ('ACS', 'PFL', 'detector', 'Y')
go
insert into cdbs_mode values ('ACS', 'PFL', 'ccdamp', 'Y')
go
insert into cdbs_mode values ('ACS', 'PFL', 'ccdgain', 'Y')
go
insert into cdbs_mode values ('ACS', 'PFL', 'filter1', 'Y')
go
insert into cdbs_mode values ('ACS', 'PFL', 'filter2', 'Y')
go
insert into cdbs_mode values ('ACS', 'PFL', 'obstype', 'Y')
go
insert into cdbs_mode values ('ACS', 'PFL', 'fw1offst', 'Y')
go
insert into cdbs_mode values ('ACS', 'PFL', 'fw2offst', 'Y')
go
insert into cdbs_mode values ('ACS', 'PFL', 'fwsoffst', 'Y')
go
insert into cdbs_mode values ('ACS', 'SHD', 'detector', 'Y')
go
insert into cdbs_mode values ('ACS', 'WCP', 'detector', 'Y')
go
insert into cdbs_mode values ('ACS', 'WCP', 'filter1', 'N')
go
insert into cdbs_mode values ('ACS', 'WCP', 'filter2', 'N')
go

insert into cdbs_mode values ('WFC3', 'BIA', 'detector', 'Y')
go
insert into cdbs_mode values ('WFC3', 'BIA', 'ccdamp', 'Y')
go
insert into cdbs_mode values ('WFC3', 'BIA', 'ccdgain', 'Y')
go
insert into cdbs_mode values ('WFC3', 'BIA', 'binaxis1', 'Y')
go
insert into cdbs_mode values ('WFC3', 'BIA', 'binaxis2', 'Y')
go
insert into cdbs_mode values ('WFC3', 'BIA', 'aperture', 'Y')
go
insert into cdbs_mode values ('WFC3', 'BIA', 'chinject', 'Y')
go
insert into cdbs_mode values ('WFC3', 'DRK', 'detector', 'Y')
go
insert into cdbs_mode values ('WFC3', 'DRK', 'ccdamp', 'Y')
go
insert into cdbs_mode values ('WFC3', 'DRK', 'ccdgain', 'Y')
go
insert into cdbs_mode values ('WFC3', 'DRK', 'samp_seq', 'Y')
go
insert into cdbs_mode values ('WFC3', 'DRK', 'subtype', 'Y')
go
insert into cdbs_mode values ('WFC3', 'DRK', 'binaxis1', 'Y')
go
insert into cdbs_mode values ('WFC3', 'DRK', 'binaxis2', 'Y')
go
insert into cdbs_mode values ('WFC3', 'PFL', 'detector', 'Y')
go
insert into cdbs_mode values ('WFC3', 'PFL', 'ccdamp', 'Y')
go
insert into cdbs_mode values ('WFC3', 'PFL', 'filter', 'Y')
go
insert into cdbs_mode values ('WFC3', 'PFL', 'binaxis1', 'Y')
go
insert into cdbs_mode values ('WFC3', 'PFL', 'binaxis2', 'Y')
go
insert into cdbs_mode values ('WFC3', 'LFL', 'detector', 'Y')
go
insert into cdbs_mode values ('WFC3', 'LFL', 'ccdamp', 'Y')
go
insert into cdbs_mode values ('WFC3', 'LFL', 'filter', 'Y')
go
insert into cdbs_mode values ('WFC3', 'DFL', 'detector', 'Y')
go
insert into cdbs_mode values ('WFC3', 'DFL', 'ccdamp', 'Y')
go
insert into cdbs_mode values ('WFC3', 'DFL', 'filter', 'Y')
go
insert into cdbs_mode values ('WFC3', 'DFL', 'binaxis1', 'Y')
go
insert into cdbs_mode values ('WFC3', 'DFL', 'binaxis2', 'Y')
go
insert into cdbs_mode values ('WFC3', 'SHD', 'detector', 'Y')
go
insert into cdbs_mode values ('WFC3', 'FLS', 'detector', 'Y')
go
insert into cdbs_mode values ('WFC3', 'FLS', 'ccdamp', 'Y')
go
insert into cdbs_mode values ('WFC3', 'FLS', 'binaxis1', 'Y')
go
insert into cdbs_mode values ('WFC3', 'FLS', 'binaxis2', 'Y')
go
insert into cdbs_mode values ('WFC3', 'BPX', 'detector', 'Y')
go
insert into cdbs_mode values ('WFC3', 'BPX', 'ccdchip', 'N')
go
insert into cdbs_mode values ('WFC3', 'CCD', 'detector', 'Y')
go
insert into cdbs_mode values ('WFC3', 'CCD', 'ccdchip', 'N')
go
insert into cdbs_mode values ('WFC3', 'CCD', 'ccdamp', 'N')
go
insert into cdbs_mode values ('WFC3', 'CCD', 'ccdgain', 'N')
go
insert into cdbs_mode values ('WFC3', 'CCD', 'ccdofsta', 'N')
go
insert into cdbs_mode values ('WFC3', 'CCD', 'ccdofstb', 'N')
go
insert into cdbs_mode values ('WFC3', 'CCD', 'ccdofstc', 'N')
go
insert into cdbs_mode values ('WFC3', 'CCD', 'ccdofstd', 'N')
go
insert into cdbs_mode values ('WFC3', 'CCD', 'binaxis1', 'N')
go
insert into cdbs_mode values ('WFC3', 'CCD', 'binaxis2', 'N')
go
insert into cdbs_mode values ('WFC3', 'LIN', 'detector', 'Y')
go
insert into cdbs_mode values ('WFC3', 'A2D', 'detector', 'Y')
go
insert into cdbs_mode values ('WFC3', 'A2D', 'ccdchip', 'N')
go
insert into cdbs_mode values ('WFC3', 'A2D', 'ccdamp', 'N')
go
insert into cdbs_mode values ('WFC3', 'A2D', 'ccdgain', 'N')
go
insert into cdbs_mode values ('WFC3', 'CRR', 'detector', 'Y')
go
insert into cdbs_mode values ('WFC3', 'CRR', 'crsplit', 'N')
go
insert into cdbs_mode values ('WFC3', 'OSC', 'detector', 'Y')
go
insert into cdbs_mode values ('WFC3', 'OSC', 'ccdchip', 'N')
go
insert into cdbs_mode values ('WFC3', 'OSC', 'ccdamp', 'N')
go
insert into cdbs_mode values ('WFC3', 'OSC', 'binx', 'N')
go
insert into cdbs_mode values ('WFC3', 'OSC', 'biny', 'N')
go
insert into cdbs_mode values ('WFC3', 'IDC', 'detector', 'Y')
go
insert into cdbs_mode values ('WFC3', 'IDC', 'filter', 'N')
go
insert into cdbs_mode values ('WFC3', 'IDC', 'detchip', 'N')
go
insert into cdbs_mode values ('WFC3', 'IDC', 'direction', 'N')
go
insert into cdbs_mode values ('WFC3', 'MDZ', 'detector', 'Y')
go

insert into cdbs_mode values ('COS', '1DX', 'detector', 'Y')
go
insert into cdbs_mode values ('COS', '1DX', 'obstype', 'Y')
go
insert into cdbs_mode values ('COS', '1DX', 'segment', 'N')
go
insert into cdbs_mode values ('COS', '1DX', 'opt_elem', 'N')
go
insert into cdbs_mode values ('COS', '1DX', 'cenwave', 'N')
go
insert into cdbs_mode values ('COS', '1DX', 'aperture', 'N')
go
insert into cdbs_mode values ('COS', 'BADT', 'detector', 'Y')
go
insert into cdbs_mode values ('COS', 'BADT', 'obsmode', 'Y')
go
insert into cdbs_mode values ('COS', 'BADT', 'segment', 'N')
go
insert into cdbs_mode values ('COS', 'BPIX', 'detector', 'Y')
go
insert into cdbs_mode values ('COS', 'BPIX', 'segment', 'N')
go
insert into cdbs_mode values ('COS', 'BRF', 'detector', 'Y')
go
insert into cdbs_mode values ('COS', 'BRF', 'segment', 'N')
go
insert into cdbs_mode values ('COS', 'BURST', 'detector', 'Y')
go
insert into cdbs_mode values ('COS', 'BURST', 'obsmode', 'Y')
go
insert into cdbs_mode values ('COS', 'BURST', 'segment', 'N')
go
insert into cdbs_mode values ('COS', 'DEAD', 'detector', 'Y')
go
insert into cdbs_mode values ('COS', 'DEAD', 'segment', 'N')
go
insert into cdbs_mode values ('COS', 'DISP', 'detector', 'Y')
go
insert into cdbs_mode values ('COS', 'DISP', 'obstype', 'Y')
go
insert into cdbs_mode values ('COS', 'DISP', 'segment', 'N')
go
insert into cdbs_mode values ('COS', 'DISP', 'opt_elem', 'N')
go
insert into cdbs_mode values ('COS', 'DISP', 'cenwave', 'N')
go
insert into cdbs_mode values ('COS', 'DISP', 'aperture', 'N')
go
insert into cdbs_mode values ('COS', 'FLAT', 'detector', 'Y')
go
insert into cdbs_mode values ('COS', 'FLAT', 'opt_elem', 'Y')
go
insert into cdbs_mode values ('COS', 'GEO', 'detector', 'Y')
go
insert into cdbs_mode values ('COS', 'LAMP', 'detector', 'Y')
go
insert into cdbs_mode values ('COS', 'LAMP', 'obstype', 'Y')
go
insert into cdbs_mode values ('COS', 'LAMP', 'segment', 'N')
go
insert into cdbs_mode values ('COS', 'LAMP', 'opt_elem', 'N')
go
insert into cdbs_mode values ('COS', 'LAMP', 'cenwave', 'N')
go
insert into cdbs_mode values ('COS', 'PHA', 'detector', 'Y')
go
insert into cdbs_mode values ('COS', 'PHA', 'segment', 'N')
go
insert into cdbs_mode values ('COS', 'PHA', 'opt_elem', 'N')
go
insert into cdbs_mode values ('COS', 'PHOT', 'detector', 'Y')
go
insert into cdbs_mode values ('COS', 'PHOT', 'obstype', 'Y')
go
insert into cdbs_mode values ('COS', 'PHOT', 'segment', 'N')
go
insert into cdbs_mode values ('COS', 'PHOT', 'opt_elem', 'N')
go
insert into cdbs_mode values ('COS', 'PHOT', 'cenwave', 'N')
go
insert into cdbs_mode values ('COS', 'PHOT', 'aperture', 'N')
go
insert into cdbs_mode values ('COS', 'TDS', 'detector', 'Y')
go
insert into cdbs_mode values ('COS', 'TDS', 'obstype', 'Y')
go
insert into cdbs_mode values ('COS', 'TDS', 'segment', 'N')
go
insert into cdbs_mode values ('COS', 'TDS', 'opt_elem', 'N')
go
insert into cdbs_mode values ('COS', 'TDS', 'aperture', 'N')
go
insert into cdbs_mode values ('COS', 'WALK', 'detector', 'Y')
go
insert into cdbs_mode values ('COS', 'WALK', 'obsmode', 'Y')
go
insert into cdbs_mode values ('COS', 'WALK', 'segment', 'N')
go
insert into cdbs_mode values ('COS', 'WCP', 'detector', 'Y')
go
insert into cdbs_mode values ('COS', 'WCP', 'obstype', 'Y')
go
insert into cdbs_mode values ('COS', 'WCP', 'opt_elem', 'N')
go
insert into cdbs_mode values ('COS', 'SPWCS', 'detector', 'Y')
go
insert into cdbs_mode values ('COS', 'SPWCS', 'obstype', 'Y')
go
insert into cdbs_mode values ('COS', 'SPWCS', 'segment', 'N')
go
insert into cdbs_mode values ('COS', 'SPWCS', 'opt_elem', 'N')
go
insert into cdbs_mode values ('COS', 'SPWCS', 'cenwave', 'N')
go
insert into cdbs_mode values ('COS', 'SPWCS', 'aperture', 'N')
go
