/*****************************************************************************/
/*                                                                           */
/*  File name :   wfc3_row.sql                                                */
/*                                                                           */
/*  Description : instrument "wfc3" row level table                          */
/*                associated file level table : wfc3_file                     */
/*                                                                           */
/*  Note :        for any given delivery, row level data should be inserted  */
/*                to "wfc3_row" prior insert file level data to "wfc3_file"    */
/*                                                                           */
/*  Modification History:                                                    */
/*                                                                           */
/*    Date       OPR      Who                       Reason                   */
/*  --------   -------    ---   -------------------------------------------  */
/*  09/02/02              mss   Original                                     */
/*  09/15/03              mss   Change ccdgain to float           */
/*  02/27/09   62082      mss   Add aperture */
/*  12/22/09   64177      mss   Add direction */
/*  05/04/11   xxxxx    mss/Gardner added IDENTITY field for unique MSSQL key */
/*  10/14/11   69530      mss   Add chinject */
/*****************************************************************************/

create table wfc3_row (
   file_name                   varchar(50) not null,
   expansion_number            int         not null,
   delivery_number             int         not null,

   /* observation_mode  */
   detector                    varchar(4)  not null,
   ccdamp                      varchar(4)  not null,
   ccdgain                     float       not null,
   binaxis1                    int         not null,
   binaxis2                    int         not null,
   samp_seq                    varchar(8)  not null,
   subtype                     varchar(8)  not null,
   filter                      varchar(7)  not null,
   ccdchip                     int         not null,
   ccdofsta                    int         not null,
   ccdofstb                    int         not null,
   ccdofstc                    int         not null,
   ccdofstd                    int         not null,
   crsplit                     int         not null,
   binx                        int         not null,
   biny                        int         not null,
   detchip                     int         not null,
   meanexp                     float       not null,
   aperture                    varchar(16) not null,
   direction                   varchar(7)  not null,
   chinject                    varchar(6)  not null,
   
   /* equivalence_class */
   equivalence_class_severe    int         not null,
   equivalence_class_moderate  int         not null,

   pedigree                    varchar(50) not null,
   observation_begin_date      datetime    null,
   observation_end_date        datetime    null,
   wfc3_row_id                 bigint IDENTITY(1,1) NOT NULL,
   comment                     text        null)
go

sp_bindefault cdbs_char_default, 'wfc3_row.detector'
go
sp_bindefault cdbs_char_default, 'wfc3_row.ccdamp'
go
sp_bindefault cdbs_float_default, 'wfc3_row.ccdgain'
go
sp_bindefault cdbs_int_default, 'wfc3_row.binaxis1'
go
sp_bindefault cdbs_int_default, 'wfc3_row.binaxis2'
go
sp_bindefault cdbs_char_default, 'wfc3_row.samp_seq'
go
sp_bindefault cdbs_char_default, 'wfc3_row.subtype'
go
sp_bindefault cdbs_char_default, 'wfc3_row.filter'
go
sp_bindefault cdbs_int_default, 'wfc3_row.ccdchip'
go
sp_bindefault cdbs_int_default, 'wfc3_row.ccdofsta'
go
sp_bindefault cdbs_int_default, 'wfc3_row.ccdofstb'
go
sp_bindefault cdbs_int_default, 'wfc3_row.ccdofstc'
go
sp_bindefault cdbs_int_default, 'wfc3_row.ccdofstd'
go
sp_bindefault cdbs_int_default, 'wfc3_row.crsplit'
go
sp_bindefault cdbs_int_default, 'wfc3_row.binx'
go
sp_bindefault cdbs_int_default, 'wfc3_row.biny'
go
sp_bindefault cdbs_int_default, 'wfc3_row.detchip'
go
sp_bindefault cdbs_float_default, 'wfc3_row.meanexp'
go
sp_bindefault cdbs_char_default, 'wfc3_row.aperture'
go
sp_bindefault cdbs_char_default, 'wfc3_row.direction'
go
