#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "ostdb.h"
#include "loadfile.h"
#include "loadutils.h"
#include "cdbs_sql_gen.h"

//
//****************************************************************************
//
// Function:     get_delivery_num
//
// Purpose:      Determines the CDBS delivery number by querying the database
//
//              The following query is performed:
//
//              UPDATE delivery_number SET value = value + 1
//              SELECT value FROM delivery_number
//              
//
// Returns:      delivery number if successful
//              ERROR if not successful
//
//****************************************************************************
//
 
int get_delivery_num(void){

  int delivery;

  ostdb_begin_transaction(STDB_CONN_1, "CDBS_SERVER", "CDBS_DB");
  ostdb_query_setup(STDB_CONN_1, "get_delivery_num", 1, STDB_SQL, 
		    "CDBS_SERVER", "CDBS_DB", NULL);

  stdb_bind_int(STDB_CONN_1, "value", &delivery);

  stdb_query(STDB_CONN_1, "update delivery_number set value = value + 1");
  stdb_query(STDB_CONN_1, "select value from delivery_number");

  while(ostdb_get_exec(STDB_CONN_1) == STDB_CONTINUE){
  }
  stdb_close_query(STDB_CONN_1);

  // If there was an error with the query - rollback
  //    
  if(ostdb_get_status(STDB_CONN_1) == OSTDB_ERROR){
    ostdb_abort_transaction(STDB_CONN_1);
    return(ERROR);
  }else{
    ostdb_end_transaction(STDB_CONN_1);
    return(delivery);
  }
}
