#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "ostdb.h"
#include "loadfile.h"
#include "loadutils.h"
#include "cdbs_sql_gen.h"

/*
******************************************************************************
*
* Function:     get_new_equiv_class
*
* Purpose:      Gets the current equivalence class value from the database, 
*               increments and updates that value in the database
*               then returns the new moderate and severe values.
*
*               The following query is performed:
*
*               SELECT value 
*               FROM equiv_class_value
*               UPDATE equiv_class_value SET value = value + 2              
*
* Returns:      a pointer to an EquivClass structure containing the new 
*               equivalence class info if successful
*               NULL if not successful 
*
* History:
* ??/??/??  ?????   ?        original
* 10/20/11  nnnnn  MSwam     split into 2 queries to work-around C-lib crash
*
******************************************************************************
*/
// prototype
int current_max_equiv_class(void);


EquivClass *get_new_equiv_class (void)
{
  // obtain current max equiv_class value from the DB
  int equiv_class_val = current_max_equiv_class();
  if (-1==equiv_class_val) return(NULL);
 
  // update the equivalence class value in the DB 
  ostdb_begin_transaction(STDB_CONN_1, "CDBS_SERVER", "CDBS_DB");
  ostdb_query_setup(STDB_CONN_1, "get_new_equiv_class", 2, STDB_SQL, 
		    "CDBS_SERVER", "CDBS_DB", NULL);

  equiv_class_val += 2;
  stdb_int_param(STDB_CONN_1, "value", equiv_class_val);

  stdb_query(STDB_CONN_1, "UPDATE equiv_class_value set value=@value");
  while(ostdb_get_exec(STDB_CONN_1) == STDB_CONTINUE){
    ;
  }
  int rec_count = stdb_record_count(STDB_CONN_1);

  stdb_close_query(STDB_CONN_1);
  
  if ((ostdb_get_status(STDB_CONN_1) != OSTDB_NORMAL) || (rec_count != 1)){
    ostdb_abort_transaction(STDB_CONN_1);
    return(NULL);
  }
  ostdb_end_transaction(STDB_CONN_1);

  // create and return the result object
  EquivClass *new_equiv=NULL;
  new_equiv = (EquivClass *)malloc(sizeof(EquivClass));
  new_equiv->sev = equiv_class_val -1;
  new_equiv->mod = equiv_class_val;
  return(new_equiv);
}

/*********************************************************************/
int current_max_equiv_class(void)
{
  // obtain the last equivalence class value used from the DB
  //
  ostdb_query_setup(STDB_CONN_1, "get_new_equiv_class", 1, STDB_SQL, 
		    "CDBS_SERVER", "CDBS_DB", NULL);

  int equiv_class_val;
  stdb_bind_int(STDB_CONN_1, "value", &equiv_class_val);

  stdb_query(STDB_CONN_1, "SELECT value FROM equiv_class_value");
  while(ostdb_get_exec(STDB_CONN_1) == STDB_CONTINUE){
    ;
  }
  int rec_count = stdb_record_count(STDB_CONN_1);

  stdb_close_query(STDB_CONN_1);
  
  if ((ostdb_get_status(STDB_CONN_1) != OSTDB_NORMAL) || (rec_count != 1)){
    // failed
    return(-1);
  }
  return(equiv_class_val);
}
