#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "cdbslib.h"
#include "alist.h"
#include "cdbserror.h"
#include "loadutils.h"

/* TASK -- Driver for the cdbslib_test task 
 *
 * i: argc	number of task arguments
 * o: argv	array of pointers to task arguments
 *
 * History:
 */

void task (int argc, char ** argv)
{
  int nfailed=0;   // assume all tests succeed
  //--------------------------------------------------------
  //addsubdir TEST
  //--------------------------------------------------------
  char rootdir[256];
  char addon_subdir[256];
  char fulldir[256];
  char success_case[256];
  strcpy(rootdir, "/here/there/overwhere/");
  strcpy(addon_subdir, "put/some/more/");
  strcpy(success_case,"/here/there/overwhere/put/some/more/");
  addsubdir (rootdir, addon_subdir, fulldir, 256);
  if (strcmp(fulldir,success_case)) {
     printf("addsubdir TEST FAILED: \nfulldir=%s\n,should have been=%s\n",fulldir,success_case);
     nfailed++;
  }
  //--------------------------------------------------------
  //alist TEST
  //--------------------------------------------------------
  alist *mylist;
  mylist = create_alist();
  add_alist(mylist, "key1", "value1");
  add_alist(mylist, "key2", "value2");
  add_alist(mylist, "key3", "value3");
  char *myKey;
  char *myVal;
  // grab the 2nd list item
  if (OK==each_alist (mylist, 1, &myKey, &myVal)) {
     if (strcmp(myKey,"key2") || strcmp(myVal,"value2")) {
        nfailed++;
        printf("each_alist: Failed to retrieve key2,value2 from alist\n");
     }
  }
  else {
     nfailed++;
     printf("each_alist: error returned from key2,value2 retrieval\n");
  }
  // make sure grabbing the 6th item is an error
  if (ERR==each_alist (mylist, 6, &myKey, &myVal)) {
  }
  else {
     nfailed++;
     printf("each_alist: failed to gen ERROR when retrieving bad index\n");
  }
  // grab an item by key
  if ((myVal = find_alist (mylist, "key3"))==NULL) {
     nfailed++;
     printf("find_alist: failed to find key3 in list\n");
  }
  else {
     if (strcmp(myVal,"value3")) {
        nfailed++;
        printf("find_alist: failed to retrieve value3\n");
     }
  }
  // do a wildcard key search
  int searchIndex=0;
  myVal = match_alist (mylist, "*2", &searchIndex);
  if (myVal) {
     if (strcmp(myVal,"value2")) {
        nfailed++;
        printf("match_alist: did NOT find value2, instead=%s\n",myVal);
     }
  } 
  else {
     nfailed++;
     printf("match_alist: returned NULL for match attempt\n");
  }
  free_alist(mylist);
  //--------------------------------------------------------
  // loadutils TEST
  //--------------------------------------------------------
  char instr[1024];
  strcpy(instr,"uppercase");
  if (strcmp("UPPERCASE",UpCase(instr))) {
     nfailed++;
     printf("UpCase: did NOT return UPPERCASE\n");
  }
  strcpy(instr,"LOWERCASE");
  if (strcmp("lowercase",LowCase(instr))) {
     nfailed++;
     printf("LowCase: did NOT return lowercase\n");
  }
  if (FALSE==NotBlank(instr)) {
     nfailed++;
     printf("NotBlank: did NOT interpret :%s: as NotBlank\n",instr);
  }
  strcpy(instr,"@#(*^*$  ");
  if (TRUE==NotBlank(instr)) {
     nfailed++;
     printf("NotBlank: did NOT interpret :%s: as Blank\n",instr);
  }
  instr[0]='\0';
  if (TRUE==NotBlank(instr)) {
     nfailed++;
     printf("NotBlank: did NOT interpret :%s: as Blank\n",instr);
  }
  strcpy(instr,"Testing a multiline\n comment with\n no embedded quotes.");
  char *outstr=NULL;
  TransformQuotes(instr, &outstr);
  if (strcmp(instr,outstr)) {
     nfailed++;
     printf("TransformQuotes: input without quote did NOT match output\n");
  }
  free(outstr); outstr=NULL;
  strcpy(instr,"Testing a multiline\n comment with\n \"embedded\" quotes.");
  TransformQuotes(instr, &outstr);
  if (strcmp(outstr,
             "Testing a multiline\n comment with\n \"\"embedded\"\" quotes.")) {
     nfailed++;
     printf("TransformQuotes: Unmatched output string :%s:\n");
  }
  free(outstr); outstr=NULL;
 
  //--------------------------------------------------------
  if (nfailed) {
    printf("FAILED.\n");
    exit(1);
  }
  else {
    printf("OK.\n");
    exit(0);  
  }
}
