#include "loadfile.h"
#include "config.h"
#include "datafile.h"
#include "cdbslib.h"
#include "certify.h"
#include "template.h"
#include "cdbserror.h"

/* TASK -- Driver for the certify task 
 *
 * i: argc	number of task arguments
 * o: argv	array of pointers to task arguments
 *
 * History:
 * 09/20/04  52054  MSwam  use topdir to fill catalog name
 * 04/08/11  67644  MSwam  use datadir to fill catalog name
 */

void task (int argc, char ** argv)
{
    char	catalog[SZ_FNAME+1], cdbs_data_dir[SZ_FNAME+1];
    char	catcols[] = CATALOG_COLS;
    table	*look;
    tpl_file	*oldtpl;
    int		iarg;

    /* define the catalog location */
    safecopy(catalog, datadir(cdbs_data_dir), SZ_FNAME);
    safecat(catalog, CATALOG_NAME, SZ_FNAME);
    cdbs_debug("CATALOG_NAME = %s\n",catalog);

    look = open_lookup (catalog, catcols);

    /* The template is cached in oldtpl, to keep from opening the template
     * file on each call of certify. Oldtpl is initially set to null to
     * show the cache is empty. After finishing the task, the cached
     * template must be freed
     */

    oldtpl = NULL;
    for (iarg = 1; iarg < argc; iarg ++) {
	 if (is_datafile (argv[iarg]) == NO)
	      certify (look, argv[iarg], oldtpl);
    }

    close_template (oldtpl);
    close_lookup (look);
}

