#include "datafile.h"
#include "config.h"
#include "error.h"
#include "cdbslib.h"
#include "loadfile.h"
#include "query_task.h"
#include "cdbserror.h"

/* TASK -- Driver for the query task
 *
 * i: argc      number of task arguments
 * i: argv      array of pointers to task arguments
 *
 * History:
 * 09/20/04  52054  MSwam  use topdir for QUERY_SEARCH,QUERY_RESULT templates
 *
 */
 
void task (int argc, char ** argv)
{
    table	*tab;
    char	*tabname;
    char	param[SZ_STRING+1], templat[SZ_FNAME+1], mytop[SZ_FNAME+1];

    /* Load command line arguments into their proper parameters 
     * Cases of the switch statements are meant to fall through
     */

    switch (argc) {
    case 4:
        sprintf (param, "qual=%s", argv[3]);
	put_option (param);

    case 3:
        sprintf (param, "columns=%s", argv[2]);
	put_option (param);

    case 2:
        sprintf (param, "table=%s", argv[1]);
	put_option (param);

    case 1:
        break;

    default:
        cdbs_error (EXTRAPAR, "%s", joinargs (argc, argv));
    }

    /* Read the cgi form input */

    form_input();

    /* Install the cgi error handler if input is from a cgi form 
     * and set default values of parameters
     */

    if (yorn (get_option ("HTML")) == YES) {
	cdbs_errhandler = cgi_error;
	def_option ("text=no");
    } else {
        def_option ("text=yes");
    }

    def_option("table=,columns=,qual=,dbase=,unique-,title+,ucase-");

    /* If there are no task parameters, show the search screen
     * otherwise, do the query and save the results in a lookup table
     */

    tabname = get_option ("table");
    safecopy(templat, topdir(mytop), SZ_FNAME);
    if (tabname[0] == EOS) {
        tab = NULL;
	safecat(templat, QUERY_SEARCH, SZ_FNAME);
    } else {
        tab = query();
	safecat(templat, QUERY_RESULT, SZ_FNAME);
    }

    /* Print the results of the query */

    if (yorn (get_option ("text")) == NO) {
        qryout_html (templat, tab);
    } else {
        qryout_text (tab);
    }
}
