#include <stdlib.h>
#include "error.h"
#include "config.h"
#include "cdbslib.h"
#include "loadfile.h"
#include "mkcomptab.h"
#include "cdbserror.h"

/* GETTHRUCOL -- Get the name of the throughput column best matching compname
 *
 * i: fname	throughput table name
 * i: compname	component name
 * o: colname	throughput column name
 * i: maxch	max length column name
 */

void getthrucol (char *fname, char *compname, char *colname, int maxch)
{
    textbuf	*collist;
    char	*thrucol;
    int		icol, score, maxscore;

    /* Create a list of throughput column names */

    collist = (textbuf *) malloc (sizeof (textbuf));
    init_text (collist, 5, 100);
 
    getthrulist (fname, collist);

    /* Select the name that is most similar to the component name */

    if (collist->nline <= 1) {
	thrucol = get_text (collist, 0);
	if (thrucol == NULL) {
	    cdbs_warn (NOTHRU, "%s", fname);
	    colname[0] = EOS;
	} else {
	    safecopy (colname, thrucol, maxch);
	}
cdbs_debug("getthrucol: found just one, %s", colname);

    } else {
	maxscore = -1;
	for (icol = 0; icol < collist->nline; icol ++) {
	    thrucol = get_text (collist, icol);
	    score = similar (compname, thrucol);
cdbs_debug("getthrucol: scoring %s against %s", thrucol, compname);
	    if (maxscore < 0 || (score > 2 && score > maxscore)) {
                /* scores less than 3 aren't really a "match" so
                 * only save the first such minimal match  */
cdbs_debug("getthrucol: SAVING a better score: %d", score);
		maxscore = score;
		safecopy (colname, thrucol, maxch);
	    }
	}
    }

    free_text (collist);
    free (collist); collist=NULL;
}
