#include <stdio.h>
#include <string.h>
#include "config.h"
#include "datafile.h"
#include "error.h"
#include "alist.h"
#include "loadfile.h"
#include "cdbslib.h"
#include "mkcomptab.h"
#include "cdbserror.h"

/* UPDATE_COMP -- Update thruput table name in the component lookup table 
 *
 * u: comptab	component lookup table
 * i: ext	required extension
 *
 * History:
 * 09/20/04  52054  MSwam   use topdir to fill THRUCAT
 * 04/08/11  67644  MSwam   use datadir instead of topdir
 *
 */

void update_comp (table *comptab)
{
    alist	*list;
    int		irow;
    char	*fname, *compname, *dir;
    char	path[SZ_FNAME+1], colname[SZ_STRING+1], newfname[SZ_LINE+1];
    char	thrucat[SZ_FNAME+1], cdbs_data_dir[SZ_FNAME+1];

    safecopy(thrucat, datadir(cdbs_data_dir), SZ_FNAME);
    safecat(thrucat, THRUCAT_NAME, SZ_FNAME);

    list = read_alist (thrucat);

    for (irow = 0; irow < nrow_table (comptab); irow ++) {
        /* Get filename and component name from lookup table */

	fname = get_tab_cell (comptab, "FILENAME", irow);
	compname = get_tab_cell (comptab, "COMPNAME", irow);
cdbs_debug("fname,compname = %s,%s", fname, compname);

	/* Get the directory name from the thruput catalog */

	dir = patmatch_alist (list, fname);
	if (dir == NULL)
	    cdbs_error (BADTHRU, "%s", fname);

	safecopy (path, dir, SZ_FNAME);
	safecat (path, fname, SZ_FNAME);

	/* Get the name of the thruput column from the thruput table */

	getthrucol (path, compname, colname, SZ_STRING);
cdbs_debug("getthrucol: path,colname= %s,%s", path, colname);

	/* If it is not "throughput", append it to the thruput table name */

	if (strcmp (colname, "throughput") != 0) {
	    sprintf (newfname, "%s[%s]", path, colname);
	} else {
	  safecopy (newfname, path, SZ_FNAME);
	}

	/* Write the thruput table name back to the lookup table */

	put_tab_cell (comptab, "FILENAME", irow, newfname);
    }

    free_alist (list);
}
