#include <string.h>
#include "error.h"
#include "config.h"
#include "loadfile.h"
#include "reffile.h"
#include "cdbslib.h"
#include "cdbserror.h"
#include "expload.h"
#include "mkload.h"

//===================================================================
//
// Name: mkload_expload_necessary
//
// Description: Does tests to determine if this loadfile needs to be
//              exploaded.
//
// Returns:     1 = expload is needed
//              0 = expload is NOT needed
// History:
// --------
// 06/08/11 68503 MSwam     first version
//
//===================================================================

int mkload_expload_necessary(
       table *loadfile_table, // io :loadfile table descriptor
       char *instrument      // i : instrument for this ref file
       )
{
    // if the filetype is a TABLE then expload is not needed
    char *filename = get_tab_key(loadfile_table, "FILE_NAME");
    char actual_file_type[10];
    if (!strcmp(type_reffile (filename, actual_file_type), "table")) {
        return 0;
    }

    // check for the existence of wildcard sentinel keyword values
    //   (nonobsmode columns don't need to be checked)
    //
    static char *wildcards = WILDCARD_LIST;
    static char *nonobsmode = "change_level|pedigree|\
observation_begin_date|observation_end_date|expansion_number|comment";

    int         icol;
    char        *obscol, *obsval;

    for (icol = 0; icol < ncol_table (loadfile_table); icol ++) {
        obscol = get_tab_colname (loadfile_table, icol);

        // skip nonobsmode columns, they won't contain wildcards
        if (!strmatch (obscol, nonobsmode)) {
            obsval = get_tab_cell_bynum (loadfile_table, icol, 0);
            if (strmatch (obsval, wildcards)) {
                // WILDCARD found, expload IS needed, no need to check further
                return 1; 
            }
        }
    }

    // no wildcards found, expload NOT needed
    return 0;
}
