#include <stdlib.h>
#include <string.h>
#include "config.h"
#include "alist.h"
#include "reffile.h"
#include "cdbslib.h"
#include "loadfile.h"
#include "mkload.h"

#define  SZ_OBSMODE	500

/* MKLOAD_COMPFILE -- Write comparson file and useafter date to header
 *
 * i: tab		table descriptor
 * i: instrument	instrument name
 * i: reftype		reference file type
 *
 * History:
 * 05/10/11  MSwam  trim multiple COMPARISON_FILE matches to just the first
 */

void mkload_compfile (table *tab, 
		      char *instrument, 
                      char *reftype)
{
    double	now;
    char	*useafter;
    int		hasdate;
    alist	*obsmode;
    char	obsquery[SZ_OBSMODE+1];
    char	compfile[SZ_FNAME+1], date[SZ_FNAME+1];

    /* Read the useafter date from the table. 
     * If not found, set it to the current time
     */

    useafter = get_tab_key (tab, "USEAFTER_DATE");
    if (useafter == NULL || useafter[0] == EOS) {
	hasdate = NO;
	useafter = (char *) malloc (SZ_STRING+1);

	now = get_now ();
	put_sybase_date (now, useafter, SZ_STRING);

    } else {
	hasdate = YES;
    }

    /* Read the observation mode from the table into an associative array 
     * then convert it into a query string
     */

    obsmode = create_alist ();

    read_obsmode (tab, obsmode);
    set_obsquery (obsmode, "b", obsquery, SZ_OBSMODE);

    free_alist (obsmode);

    /* Query the database for the comparison file and its useafter date */

    compfile_qry (instrument, reftype, useafter, obsquery, 
		  compfile, date, SZ_FNAME);

    // if multiple files came back, only use the LAST one
    char *lastCompFile=compfile;
    char *commaPos=NULL;
    if ((commaPos=strrchr(compfile,','))!=NULL) {
       lastCompFile = ++commaPos;
    }
    /* Write to the table, if found */

    if (compfile[0] != EOS) {
	put_tab_key (tab, "COMPARISON_FILE", lastCompFile);

	if (hasdate == NO)
	    put_tab_key (tab, "USEAFTER_DATE", date);
    }

    if (hasdate == NO) {
	free (useafter); useafter=NULL;
    }

}
