#include <string.h>
#include "error.h"
#include "config.h"
#include "loadfile.h"
#include "reffile.h"
#include "cdbslib.h"
#include "cdbserror.h"
#include "mkload.h"

//===================================================================
// MKLOAD_HEADER -- Write header keywords to table
//
// i: tab		table descriptor
// i: reffile_name      reference file name
// i: instrument	instrument associated with reference file
// i: reftype		reference file type
// i: filetype          image or table
//
//===================================================================

void mkload_header (table *tab, 
                    char *reffile_name, 
                    char *instrument, 
                    char *reftype,
                    char *filetype)
{
    // open the primaryHDU or first group of the reference file
    reffile *ref = open_reffile_hdr (reffile_name, filetype, "r");
    if (ref == NULL) {
        fprintf(stderr,"Failed to open %s as type=%s\n",
                        reffile_name, filetype);
        cdbs_warn (NOTOPEN, "%s", reffile_name);
        return;
    }

    // Write filename to loadfile header
    put_tab_key (tab, "FILE_NAME", localname (name_reffile(ref)));

    // Write the instrument and reference file type
    put_tab_key (tab, "INSTRUMENT", instrument);
    put_tab_key (tab, "REFERENCE_FILE_TYPE", reftype);

    // Get useafter date from the reference file header, if present
    //
    char useafter[SZ_STRING+1]; 
    char date[SZ_STRING+1];
    if (get_hdr_reffile (ref, "useafter", useafter, SZ_STRING) == ERR) {
	date[0] = EOS;
    } else {
	mkload_date (useafter, date, SZ_STRING);
    }
    put_tab_key (tab, "USEAFTER_DATE", date);

    // Set comparsion file to initial value for now
    put_tab_key (tab, "COMPARISON_FILE", "(INITIAL)");

    // Set remaining loadfile header keywords to blank
    char nilstr[] = "";
    put_tab_key (tab, "OPUS_FLAG", nilstr);
    put_tab_key (tab, "COMMENT", nilstr);

    close_reffile(ref);
    return;
}
