#include <string.h>
#include "ostdb.h"
#include "dbquery.h"
#include "config.h"
#include "loadfile.h"
#include "cdbslib.h"
#include "getref.h"

/* BEST_FILES -- Retrieve best reference files from database
 *
 * i: qry	query context
 * i: file_type	observation set type (science or wavecal)
 * i: dataset	dataset reference files are for
 * u: tab	table containing keyword changes
 */

void best_files (context *qry, char *file_type, char *dataset, table *tab) {

    textbuf	*files;
    int		text, code, irow, ivar, ifile, done;
    char	**bestvar, **oldvar;
    char	*change, *oper, *fname;
    char	*keyword[MAXKEYS+1], *bestref[MAXKEYS+1];
    char	*oldref[MAXKEYS+1];

    static char	*bestqryfmt = "select {[, ]^}, {[, ]^} from ^ where ^ = ^";

    text = yorn (get_option ("text"));

    /* Retrieve an array of best keyword fields, return if none found */

    if (get_keywords (qry, dataset, file_type, "ref_file", keyword, 
		      bestref, oldref, MAXKEYS) == ERR) 
        return;

    /* Get files that reference file names will be written to */

    files = which_files (qry, dataset, file_type, "ref_file");

    /* Initialize query */

    ostdb_query_setup (qry->connection, "best_file", 1, STDB_SQL,
		       qry->server, qry->dads_db, db_error);

    /* Bind variables receiving query results */

    code = get_icode_obs (dataset);
    oldvar = bind_qryvars (qry->connection, oldref);
    bestvar = bind_qryvars (qry->connection, bestref);

    /* Build the query and send to database */

    build_qry (qry->connection, bestqryfmt, oldref, bestref, dadstab[code], 
	       obsfield[code], strucase (enquote (dataset)));

    /* Execute query and write results to table */

    irow = nrow_table (tab);
    while (ostdb_get_exec (qry->connection) == STDB_CONTINUE) {

	/* Write results for each keyword */

	for (ivar = 0; keyword[ivar][0] != EOS; ivar ++) {
	    clean_data (bestvar[ivar]);
	    clean_data (oldvar[ivar]);

	    if (bestvar[ivar][0] == EOS)
		strcpy (bestvar[ivar], oldvar[ivar]);

	    if (streq (bestvar[ivar], oldvar[ivar])) {
		change = "no";
	    } else {
		change = "yes";
	    }

	    if (is_reffile (bestvar[ivar]) == NO) {
		oper = "update";
	    } else {
		oper = "insert";
	    }

	    /* Loop over each file the keyword is to be written to */

	    for (ifile = 0;
		 (fname = get_text (files, ifile)) != NULL; 
		 ifile ++) {

		put_tab_cell (tab, "ROOTNAME", irow, dataset);
		put_tab_cell (tab, "KEYWORD", irow, keyword[ivar]);

		if (is_reffile(bestvar[ivar]) == NO) {
		    strucase (bestvar[ivar]);
		    put_tab_cell (tab, "VALUE", irow, bestvar[ivar]);

		} else if (text == YES) {
		    put_tab_cell (tab, "VALUE", irow, bestvar[ivar]);

		} else {
		    put_tab_cell (tab, "VALUE", irow, 
				  mkanchor (bestvar[ivar], dataset, 
					    bestvar[ivar], ""));
		}

		put_tab_cell (tab, "FILENAME", irow, fname);
		put_tab_cell (tab, "OPERATION", irow, oper);
		put_tab_cell (tab, "CHANGE", irow, change);
		put_tab_cell (tab, "SOURCE", irow, "ref");

		irow ++;
	    }
	}
    }

    stdb_close_query (qry->connection);

    done = NO;
    for (ivar = 0; done == NO; ivar ++) {
	if (keyword[ivar][0] == EOS)
	    done = YES;

	free (keyword[ivar]);
	free (oldref[ivar]);
	free (bestref[ivar]);
    }

    free_qryvars (bestvar);
    free_qryvars (oldvar);
    free_files (files);
}
