#include <string.h>
#include "cdbslib.h"
#include "getref.h"

/* BUILD_FNAME -- Build a file name from its component parts
 *
 * i: root	filename root
 * i: ext	filename extension
 * i: extname	image extension name or group name
 * i: extver	image extension version or group number
 * o: fname	filename generated from these parts
 * i: maxch	maximum length of filename
 */

void build_fname (char *root, char *ext, char *extname, int extver,
		  char *fname, int maxch) {

    int		code, fits, nc;
    char	section[SZ_STRING+1];

    /* Check to see if this instrument only uses fits files, if not, 
     * the user can specify fits or not with the option fits
     */

    code = get_icode_obs (root);
    fits = is_fits[code];
    if (is_fits[code] == NO)
	fits = yorn (get_option ("fits"));

    if (fits == NO) {
	/* Root name gets copied into filename first */
	safecopy (fname, root, maxch);

	/* Glom on extension, check for leading dot */
	if (ext[0] != '.')
	    safecat (fname, ".", maxch);

	safecat (fname, ext, maxch);

	/* Add group specifier if nonzero */
	if (extver != 0) {
	    sprintf (section, "[%d]", extver);
	    safecat (fname, section, maxch);
	}

    } else {
	/* Root name gets copied into filename first */
	safecopy (fname, root, maxch);

	/* Then extension, separated by an underscore */
	safecat (fname, "_", maxch);

	if (ext[0] != '.') {
	    safecat (fname, ext, maxch);
	} else {
	    safecat (fname, &ext[1], maxch);
	}

	/* Last letter of extension gets changed to f */
	nc = strlen (fname);
	if (fname[nc-1] == 'h')
	    fname[nc-1] = 'f';

	/* Filename extension is always fits */
	safecat (fname, ".fits", maxch);

	/* The full extension specifier is only copied if this
	 * is not the primary header
	 */
	if (extver != 0) {
	    sprintf (section, "[%s,%d]", extname, extver);
	} else {
	    safecopy (section, "[0]", SZ_STRING);
	}

	safecat (fname, section, maxch);
    }

}
