#include <unistd.h>
#include <string.h>
#include "ostdb.h"
#include "config.h"
#include "cdbslib.h"
#include "loadfile.h"
#include "dbquery.h"
#include "getref.h"

#define  LOCK_MAX	8	/* Max num times to check lock */
#define  LOCK_WAIT	15	/* Wait in secs between checks */
#define  LOCK_VALUE	"y"	/* Value in db when file is locked */

/* CHECK_LOCK -- See if dataset has been locked in the database
 *
 * i: qry	query context
 * i: dataset	observation dataset to be checked
 */

int check_lock (context *qry, char *dataset) {

    int		code, retry, try, maxtry;
    char	lockval[SZ_STRING+1];

    static char *lock_fmt = "select ^ from ^ holdlock where ^ = ^";

    /* Check for the existence of the lock field */

    code = get_icode_obs (dataset);

    if (strcmp (lockfield[code], "?") == 0)
        return OK;

    /* Set maximum number of attempts to check lock */

    retry = yorn (get_option ("retry"));

    if (retry == NO) {
	maxtry = 1;
    } else {
	maxtry = LOCK_MAX;
    }

    /* Make several attempts to access an observation if it is locked */

    for (try = 0; try < maxtry; try ++) {
	/* Initialize database query */

	ostdb_query_setup (qry->connection, "check_lock", try+1, STDB_SQL,
			   qry->server, qry->dads_db, db_error);

	stdb_bind_string (qry->connection, lockfield[code], lockval, 
			  SZ_STRING);

	build_qry (qry->connection, lock_fmt, lockfield[code], dadstab[code],
		   obsfield[code], strucase (enquote (dataset)));

	/* Check lock field to see if file is locked. 
	 * Break if obervation not found in database
	 * or lock field is not set
	 */


	if (ostdb_get_exec (qry->connection) != STDB_CONTINUE) {
	    stdb_close_query (qry->connection);
	    break;

	} else {
	    clean_data (lockval);

	    if (streq (lockval, LOCK_VALUE)) {
		stdb_close_query (qry->connection);
		if (try + 1 < maxtry) {
		    set_transact (qry, dataset, STOP);
		    sleep (LOCK_WAIT);
		    set_transact (qry, dataset, START);
		}

	    } else {
		stdb_close_query (qry->connection);
		break;
	    }
	}
    }

    /* Return success if dataset not locked */

    return (try < maxtry ? OK : ERR);
}
