#include <stdlib.h>
#include "error.h"
#include "dbquery.h"
#include "config.h"
#include "loadfile.h"
#include "cdbslib.h"
#include "getref.h"

/* GETREF_ALL -- Get summary information on all reference files
 *
 */

table *getref_all (void)
{
    table 	*tab;
    context	*qry;
    textbuf	*list;
    char	*dataset, *root;
    int		ilist;

    qry = init_query ();
    tab = create_table();

    /* Expand association names into individual member names */

    list = expand_assoc (qry);

    /* Loop over each observation set rootname in the list  */

    for (ilist = 0; (dataset = get_text (list, ilist)) != NULL; ilist ++) {
	set_transact (qry, dataset, START);

	/* Check database to see if dataset record is locked for update */

	if (check_lock (qry, dataset) == OK) {

	    /* Set keyword if dataset should not be calibrated */
	    set_calibrate (qry, dataset, tab);

	    /* Retrieve best reference files */
	    best_files (qry, "science", dataset, tab);

	    /* Retrieve perform/omit switches */
	    best_switches (qry, dataset, tab);

	    /* Retrieve other keyword changes */
	    key_changes (qry, dataset, tab);

	    /* Check for wavecal file associated with observation */

	    if (has_wavecal (qry, dataset) == YES) {

		/* Retrieve wavecal best reference files */
		best_files (qry, "wavecal", dataset, tab);

		/* Retrieve wavecal perform/omit switches */
		wav_switches (qry, dataset, tab);
	    }

	} else {
	    cdbs_warn (DBLOCK, "%s", dataset);
	}

	set_transact (qry, dataset, STOP);
    }

    free_assoc (list);
    free_query (qry);

    /* Complain if no results */

    if (nrow_table (tab) == 0) {
	root = get_option ("root");
	cdbs_error (NOROOT, "%s", root);
    }

    /* Sort table on dataset name before returning it */

    tab = sort_table (tab, "FILENAME");

    if (tab == NULL)
	cdbs_error (NOSORT, "%s", lod_error);

    return tab;
}
