#include <string.h>
#include "ostdb.h"
#include "config.h"
#include "cdbslib.h"
#include "dbquery.h"
#include "getref.h"

#define  WAVECAL_TABLE		"stis_ref_data"
#define  WAVECAL_FIELD		"ssr_wavecal"

/* HAS_WAVECAL -- Check if this observation has an associated wavecal file
 *
 * i: qry	query context
 * i: dataset	observation dataset to be checked
 */

int has_wavecal (context *qry, char *dataset) {

    int		code, status;
    char	wavecal[SZ_STRING+1];

    static char *wavecal_fmt = "select ^ from ^ where ^ = ^";

    /* Check to see if this is a stis observation */

    code = get_icode_obs (dataset);
    if (strcmp (dadstab[code], WAVECAL_TABLE) != 0)
	return NO;

    /* Set up query to retrieve wavecal field */

    ostdb_query_setup (qry->connection, "has_wavecal", 1, STDB_SQL,
		       qry->server, qry->dads_db, db_error);

    stdb_bind_string (qry->connection, WAVECAL_FIELD, wavecal, SZ_STRING);

    build_qry (qry->connection, wavecal_fmt, WAVECAL_FIELD, dadstab[code], 
	       obsfield[code], strucase (enquote (dataset)));
		   
    /* If wavecal field contains a wavecal filename, 
     * this obsevation has an associated wavecal file
     */

    if (ostdb_get_exec (qry->connection) == STDB_CONTINUE) {
	clean_data (wavecal);
	status = is_wavefile (wavecal);

    } else {
	status = NO;
    }

    stdb_close_query (qry->connection);
    return status;
}
