#include <string.h>
#include <stdlib.h>
#include "ostdb.h"
#include "error.h"
#include "dbquery.h"
#include "config.h"
#include "loadfile.h"
#include "cdbslib.h"
#include "getref.h"

#define  KEYNAME_FIELD		"okr_keyword"
#define  NEWKEY_FIELD		"okr_new_keyword_value"
#define  OLDKEY_FIELD		"okr_old_keyword_value"
#define  OPER_FIELD		"okr_operation"
#define  EXT_FIELD		"okr_file_extension"
#define  EXTNAME_FIELD		"okr_extname"
#define  EXTVER_FIELD		"okr_extver"
#define  CHANGE_STATUS		"ACTIVE"

#define  INSERT_CODE		1
#define  DELETE_CODE		2
#define  UPDATE_CODE		3

/* KEY_CHANGES -- Retrieve changes to miscelaneous keywords
 *
 * i: qry	database query context
 * i: dataset	observation set changes are associated with
 * o: tab	table containing changed keyword information
 */

void key_changes (context *qry, char *dataset, table *tab) {

    char	*change;
    int		irow, extver;
    char	keyname_buf[SZ_STRING+1], newkey_buf[SZ_STRING+1];
    char	oldkey_buf[SZ_STRING+1], oper_buf[SZ_STRING+1];
    char	ext_buf[SZ_STRING+1], extname_buf[SZ_STRING+1];
    char	status[SZ_STRING+1], setname[SZ_FNAME+1];
    char	fname[SZ_FNAME+1];

    static char	*oper_list = "insert|delete|update";
    static char *change_fmt = "select okr_file_extension, okr_extname, "
	"okr_extver, okr_keyword, okr_new_keyword_value, "
	"okr_old_keyword_value, okr_operation from otfc_keyword_repair "
	"where  okr_state = ^ and okr_data_set_name = ^";

    /* Set up query */

    ostdb_query_setup (qry->connection, "key_changes", 1, STDB_SQL,
		       qry->server, qry->dads_db, db_error);

    stdb_bind_string (qry->connection, KEYNAME_FIELD, keyname_buf, SZ_STRING);
    stdb_bind_string (qry->connection, NEWKEY_FIELD, newkey_buf, SZ_STRING);
    stdb_bind_string (qry->connection, OLDKEY_FIELD, oldkey_buf, SZ_STRING);
    stdb_bind_string (qry->connection, OPER_FIELD, oper_buf, SZ_STRING);
    stdb_bind_string (qry->connection, EXT_FIELD, ext_buf, SZ_STRING);
    stdb_bind_string (qry->connection, EXTNAME_FIELD, extname_buf, SZ_STRING);
    stdb_bind_int (qry->connection, EXTVER_FIELD, &extver);

    safecopy (status, strucase (enquote (CHANGE_STATUS)), SZ_STRING);
    safecopy (setname, strucase (enquote (dataset)), SZ_FNAME);

    build_qry (qry->connection, change_fmt, status, setname);

    /* Write query results to table */

    irow = nrow_table (tab);
    while (ostdb_get_exec (qry->connection) == STDB_CONTINUE) {
	clean_data (keyname_buf);
	clean_data (newkey_buf);
	clean_data (oldkey_buf);
	clean_data (oper_buf);
	clean_data (ext_buf);
	clean_data (extname_buf);

	/* Create file names from database fields */

	build_fname (dataset, ext_buf, extname_buf, extver, fname, SZ_FNAME);

	/* Check operations field for legality and convert to full string */

	switch (strabbrev (oper_buf, oper_list)) {
	case INSERT_CODE:
	    safecopy (oper_buf, "insert", SZ_STRING);
	    break;
	case DELETE_CODE:
	    safecopy (oper_buf, "delete", SZ_STRING);
	    break;
	case UPDATE_CODE:
	    safecopy (oper_buf, "update", SZ_STRING);
	    break;
	default:
	    cdbs_error (NOMATCH, "%s", oper_buf);
	}

	/* Determine if there is a change */

	if (streq (newkey_buf, oldkey_buf)) {
	    change = "no";
	} else {
	    change = "yes";
	}

	if (is_reffile (newkey_buf) == NO)
	    strucase (newkey_buf);

	/* Add new row to table */

	put_tab_cell (tab, "ROOTNAME", irow, dataset);
	put_tab_cell (tab, "KEYWORD", irow, keyname_buf);
	put_tab_cell (tab, "VALUE", irow, newkey_buf);
	put_tab_cell (tab, "FILENAME", irow, fname);
	put_tab_cell (tab, "OPERATION", irow, oper_buf);
	put_tab_cell (tab, "CHANGE", irow, change);
	put_tab_cell (tab, "SOURCE", irow, "okr");

	irow ++;
    }

    stdb_close_query (qry->connection);
}
