#include <stdlib.h>
#include "ostdb.h"
#include "config.h"
#include "cdbslib.h"
#include "loadfile.h"
#include "dbquery.h"
#include "getref.h"

#define  CALIB_STATUS 	"ACTIVE"	/* db status indicating exception */
#define  CALIB_KEYNAME	"calibrat"	/* name of keyword to write */
#define  CALIB_KEYVAL	"NO"		/* value of keyword to write */

/* SET_CALIBRATE -- See if CALIBRAT keyword should be added as header keyword
 *
 * i: qry	Database query context
 * i: dataset	Dataset to be checked
 * u: tab	Table holding keywors to be updated
 */

void set_calibrate (context *qry, char *dataset, table *tab) {

    int		irow, ifile;
    char	*fname;
    textbuf	*files;
    char	lockval[SZ_STRING+1], status[SZ_STRING+1], setname[SZ_FNAME+1];

    static char *calib_fmt = "select obc_state from otfc_bypass_calibration "
	"where obc_data_set_name = ^ and obc_state = ^";

    /* Create the list of filenames the calibrat keyword is written in */

    files = which_files (qry, dataset, "science", "calibrat");

    /* Initialize database query */

    ostdb_query_setup (qry->connection, "set_calibrate", 1, STDB_SQL,
		       qry->server, qry->dads_db, db_error);

    stdb_bind_string (qry->connection, "obc_state", lockval, SZ_STRING);

    safecopy (setname, strucase (enquote (dataset)), SZ_FNAME);
    safecopy (status, strucase (enquote (CALIB_STATUS)), SZ_STRING);

    build_qry (qry->connection, calib_fmt, setname, status);

    /* If dataset is mentioned in the dataset exceptions table
     * add a record to the table indicating that the CALIBRAT
     * keyword should be set
     */

    if (ostdb_get_exec (qry->connection) == STDB_CONTINUE) {

	irow = nrow_table (tab);
	for (ifile = 0; (fname = get_text (files, ifile)) != NULL; ifile ++) {
	    /* Add a row to the file saying the keyword should be changed */

	    put_tab_cell (tab, "ROOTNAME", irow, dataset);
	    put_tab_cell (tab, "KEYWORD", irow, CALIB_KEYNAME);
	    put_tab_cell (tab, "VALUE", irow, CALIB_KEYVAL);
	    put_tab_cell (tab, "FILENAME", irow, fname);
	    put_tab_cell (tab, "OPERATION", irow, "insert");
	    put_tab_cell (tab, "CHANGE", irow, "yes");
	    put_tab_cell (tab, "SOURCE", irow, "obc");

	    irow ++;
	}
    }

    stdb_close_query (qry->connection);
    free_files (files);
}
