#include <string.h>
#include "ostdb.h"
#include "error.h"
#include "dbquery.h"
#include "config.h"
#include "loadfile.h"
#include "cdbslib.h"
#include "getref.h"

#define  WAVECAL_OBSFIELD	"ssf_data_set_name"
#define  WAVECAL_REFTAB		"stis_ref_data2"

/* WAV_SWITCHES -- Retrieve best reference files from database
 *
 * i: qry	query context
 * i: dataset	dataset reference files are for
 * u: tab	table containing keyword changes
 */

void wav_switches (context *qry, char *dataset, table *tab) {

    textbuf	*files;
    int		irow, ivar, ifile, done;
    char	**bestvar, *oper, *fname;
    char	*keyword[MAXKEYS+1], *bestswitch[MAXKEYS+1];
    char	*oldswitch[MAXKEYS+1];

    static char	*bestqryfmt = "select {[, ]^} from ^ where ^ = ^";

    /* Retrieve an array of switch keyword fields */

    if (get_keywords (qry, dataset, "wavecal", "switch", keyword, 
		      bestswitch, oldswitch, MAXKEYS) == ERR)
        return;

    /* Get files that perform/omit will be written to */

    files = which_files (qry, dataset, "wavecal", "switch");

    /* Initialize query */

    ostdb_query_setup (qry->connection, "wav_switches", 1, STDB_SQL,
		       qry->server, qry->dads_db, db_error);

    /* Bind variables receiving query results */

    bestvar = bind_qryvars (qry->connection, bestswitch);

    /* Build the query and send to database */

    build_qry (qry->connection, bestqryfmt, bestswitch, WAVECAL_REFTAB,
	       WAVECAL_OBSFIELD, strucase (enquote (dataset)));

    /* Execute query and write results to table */

    irow = nrow_table (tab);
    while (ostdb_get_exec (qry->connection) == STDB_CONTINUE) {

	/* Write results for each keyword */

	for (ivar = 0; keyword[ivar][0] != EOS; ivar ++) {
	    clean_data (bestvar[ivar]);

	    if (check_switch (bestvar[ivar]) == ERR)
		cdbs_warn (BADKEYVAL, "%s.%s = %s", dataset, 
			   bestswitch[ivar], bestvar[ivar]);

	    /* Don't write blank switch values */

	    if (bestvar[ivar][0] == EOS)
		continue;	

	    strucase (bestvar[ivar]);

	    if (streq (bestvar[ivar], "PERFORM")) {
		oper = "insert";
	    } else {
		oper = "update";
	    }

	    /* Loop over each file the keyword is to be written to */

	    for (ifile = 0;
		 (fname = get_text (files, ifile)) != NULL; 
		 ifile ++) {

		put_tab_cell (tab, "ROOTNAME", irow, dataset);
		put_tab_cell (tab, "KEYWORD", irow, keyword[ivar]);
		put_tab_cell (tab, "VALUE", irow, bestvar[ivar]);
		put_tab_cell (tab, "FILENAME", irow, fname);
		put_tab_cell (tab, "OPERATION", irow, oper);
		put_tab_cell (tab, "CHANGE", irow, "unknown");
		put_tab_cell (tab, "SOURCE", irow, "ref");

		irow ++;
	    }
	}
    }

    stdb_close_query (qry->connection);

    done = NO;
    for (ivar = 0; done == NO; ivar ++) {
	if (keyword[ivar][0] == EOS)
	    done = YES;

	free (keyword[ivar]);
	free (oldswitch[ivar]);
	free (bestswitch[ivar]);
    }

    free_qryvars (bestvar);
    free_files (files);
}
