#include <stdlib.h>
#include "ostdb.h"
#include "error.h"
#include "cdbslib.h"
#include "dbquery.h"
#include "getref.h"

#define  EXT_FIELD	"oke_file_extension"

/* WHICH_FILES -- Which files contain the indicated keyword
 *
 * i: qry	dtabase context
 * i: dataset	Observation set name
 * i: file_type	File type (science or wavecal)
 * i: key_type	Keyword type (ref_file, switch, or calibrat)
 */

textbuf *which_files (context *qry, char *dataset, char* file_type, 
		      char *key_type) {

    textbuf	*files;
    int		code, ifile;
    char	inst[SZ_STRING+1], ty_file[SZ_STRING+1], ty_key[SZ_STRING+1];
    char	ext[SZ_STRING+1], fname[SZ_FNAME+1];

    static char *extend_fmt = "select oke_file_extension from "
	"otfc_keyword_extensions where oke_instrument = ^ and "
	"oke_file_type = ^ and oke_keyword_type = ^";

    /* Check file and keyword types for legal value */

    if (strmatch (file_type, FILE_TYPE) == 0)
	cdbs_error (NOMATCH, "in which_files: file_type = %s", file_type);

    if (strmatch (key_type, KEYWORD_TYPE) == 0)
	cdbs_error (NOMATCH, "in which_files: key_type = %s", key_type);

    /* Construct query to get list of extensions */

    code = get_icode_obs (dataset);

    ostdb_query_setup (qry->connection, "get_extension", 1, STDB_SQL,
		       qry->server, qry->dads_db, db_error);

    stdb_bind_string (qry->connection, EXT_FIELD, ext, SZ_STRING);

    safecopy (inst, strucase (enquote (inst_dads[code])), SZ_STRING);
    safecopy (ty_file, strucase (enquote (file_type)), SZ_STRING);
    safecopy (ty_key, strucase (enquote (key_type)), SZ_STRING);

    build_qry (qry->connection, extend_fmt, inst, ty_file, ty_key);

    /* Set up text buffer to hold file names */

    files = (textbuf *) malloc (sizeof (textbuf));
    init_text (files, 5, 100);
    ifile = 0;
    
    /* Retrieve extensions from database, selected by instrument type */

    while (ostdb_get_exec (qry->connection) == STDB_CONTINUE) {
	clean_data (ext);

	/* Glom extension onto dataset name to build filename */

	build_fname (dataset, ext, "", 0, fname, SZ_FNAME);
	add_text (files, fname);
	ifile ++;
    }

    stdb_close_query (qry->connection);

    if (ifile == 0)
	cdbs_error (NOINST, "%s not in otfc_keyword_extensions", 
		    inst_dads[code]);

    return files;
}

/* FREE_FILES -- Free list generated by which_files
 *
 * i: files	list of association member names
 */

void free_files (textbuf *files) {

    free_text (files);
    free (files);
}
