#include <string.h>
#include "config.h"
#include "cdbslib.h"
#include "loadfile.h"
#include "error.h"
#include "cdbserror.h"

#define  DQUOTE			'"'
#define  SQUOTE			'\''
#define  ESCAPE			'\\'
#define	 SZ_BUFFER		503

//======================================================================
// STRING LIBRARY ROUTINE
//   Name: enquote
//======================================================================

//======================================================================
// ENQUOTE -- Surround a string with single quotes
//
// i: str	string to be quoted
//
//======================================================================

char * enquote (char *str)
{
    char	quote;
    int		ic, jc;
    static char	buffer[SZ_BUFFER+1];

    /* See if string contains embedded quotes. If so, 
     * use the opposite kind of quotes to surround it
     */

    // prefer single quotes, since MSSQL does
    if (strchr (str, SQUOTE) == NULL) {
	quote = SQUOTE;
    } else if (strchr (str, DQUOTE) == NULL) {
	quote = DQUOTE;
    } else {
	quote = EOS;
    }

    if (quote != EOS) {
	/* Simple case: no quotes or only one type of quotes 
	 * Surround string with appropriate quote marks
	 */

	if (strlen (str) > SZ_BUFFER - 2) {
	    safecopy (buffer, str, 40);
	    cdbs_error (TOOLONG, "enquote: %s", buffer);
	}

	sprintf (buffer, "%c%s%c", quote, str, quote);

    } else {
	/* Complex case: both kinds of quotes
	 * escape quote marks with backslashes
	 */

	buffer[0] = SQUOTE;
	jc = 1;

	for (ic = 0; str[ic] != EOS && jc < SZ_BUFFER-1; ic ++, jc++) {
	    if (str[ic] == DQUOTE || str[ic] == SQUOTE)
		buffer[jc++] = ESCAPE;

	    buffer[jc] = str[ic];
	}

	if (jc < SZ_BUFFER-1) {
	    buffer[jc++] = SQUOTE;
	    buffer[jc] = EOS;

	} else {
	    buffer[40] = EOS;
	    cdbs_error (TOOLONG, "enquote: %s", buffer);
	}
    }

    return (buffer);
}
