# include <string.h>
# include <fitsio.h>
# include "cimages.h"

Bool c_imgetb (IRAFPointer ip, char *keyword) {

/* Get a boolean keyword from a header.
arguments:
IRAFPointer ip          i: image descriptor
char *keyword           i: keyword name

function value          o: value (True or False) for the keyword
*/

        ImageDescr *im_descr;
        int value;
        int status = 0;

        im_descr = (ImageDescr *)ip;

        /* fits_read_key = ffgky */
        clearError();
        fits_read_key (im_descr->fptr, TLOGICAL, keyword,
                        &value, NULL, &status);
        if (status != 0)
            setError (status, "c_imgetb:  error reading keyword");

        if (value)
            return True;
        else
            return False;
}

double c_imgetd (IRAFPointer ip, char *keyword) {

/* Get a keyword of type double from a header.
arguments:
IRAFPointer ip          i: image descriptor
char *keyword           i: keyword name

function value          o: value for the keyword
*/

        ImageDescr *im_descr;
        double value;
        int status = 0;

        im_descr = (ImageDescr *)ip;

        /* fits_read_key = ffgky */
        clearError();
        fits_read_key (im_descr->fptr, TDOUBLE, keyword,
                        &value, NULL, &status);
        if (status != 0)
            setError (status, "c_imgetd:  error reading keyword");

        return value;
}

float c_imgetr (IRAFPointer ip, char *keyword) {

/* Get a keyword of type float from a header.
arguments:
IRAFPointer ip          i: image descriptor
char *keyword           i: keyword name

function value          o: value for the keyword
*/

        ImageDescr *im_descr;
        float value;
        int status = 0;

        im_descr = (ImageDescr *)ip;

        /* fits_read_key = ffgky */
        clearError();
        fits_read_key (im_descr->fptr, TFLOAT, keyword,
                        &value, NULL, &status);
        if (status != 0)
            setError (status, "c_imgetr:  error reading keyword");

        return value;
}

int c_imgeti (IRAFPointer ip, char *keyword) {

/* Get an integer keyword from a header.
arguments:
IRAFPointer ip          i: image descriptor
char *keyword           i: keyword name

function value          o: value for the keyword
*/

        ImageDescr *im_descr;
        int value;
        int status = 0;

        im_descr = (ImageDescr *)ip;

        /* fits_read_key = ffgky */
        clearError();
        fits_read_key (im_descr->fptr, TINT, keyword,
                        &value, NULL, &status);
        if (status != 0)
            setError (status, "c_imgeti:  error reading keyword");

        return value;
}

void c_imgstr (IRAFPointer ip, char *keyword, char *text, int maxch) {

/* Get a string keyword from a header.
arguments:
IRAFPointer ip          i: image descriptor
char *keyword           i: keyword name
char *text              o: value for the keyword
int maxch               i: maximum length of the string (not including '\0')
*/

        ImageDescr *im_descr;
        char value[SZ_FNAME+1]; /* hopefully large enough for any keyword */
        char comment[SZ_FITS_STR+1];
        int status = 0;

        im_descr = (ImageDescr *)ip;

        /* fits_read_key = ffgky */
        clearError();
        fits_read_key (im_descr->fptr, TSTRING, keyword,
                        value, comment, &status);
        if (status != 0)
            setError (status, "c_imgetd:  error reading keyword");

        /* WORK AROUND: if the HISTORY or COMMENT keyword was asked for,
         *              its value under CFITSIO is found in the comment
         *              variable, not the value
         */
        if (strcmp(keyword, "history")==0 || strcmp(keyword,"comment")==0 ||
            strcmp(keyword, "HISTORY")==0 || strcmp(keyword,"COMMENT")==0) {
           copyString (text, comment, maxch);
        }
        else {
           copyString (text, value, maxch);
        }
}
