# include <string.h>
# include <fitsio.h>
# include "cimages.h"

void c_imhadb (IRAFPointer ip, char *keyword, Bool value) {

/* Update or add a boolean keyword to a header.
arguments:
IRAFPointer ip          i: image descriptor
char *keyword           i: keyword name
Bool value              i: value (True or False) for the keyword
*/

        ImageDescr *im_descr;
        int status = 0;

        im_descr = (ImageDescr *)ip;

        /* fits_update_key = ffuky */
        clearError();
        fits_update_key (im_descr->fptr, TLOGICAL, keyword, &value,
                                NULL, &status);
        if (status != 0)
            setError (status, "c_imhadb:  error updating keyword");
}

void c_imhadd (IRAFPointer ip, char *keyword, double value) {

/* Update or add a keyword of type double to a header.
arguments:
IRAFPointer ip          i: image descriptor
char *keyword           i: keyword name
double value            i: value for the keyword
*/

        ImageDescr *im_descr;
        int status = 0;

        im_descr = (ImageDescr *)ip;

        clearError();
        fits_update_key (im_descr->fptr, TDOUBLE, keyword, &value,
                                NULL, &status);
        if (status != 0)
            setError (status, "c_imhadd:  error updating keyword");
}

void c_imhadr (IRAFPointer ip, char *keyword, float value) {

/* Update or add a keyword of type float to a header.
arguments:
IRAFPointer ip          i: image descriptor
char *keyword           i: keyword name
float value             i: value for the keyword
*/

        ImageDescr *im_descr;
        int status = 0;

        im_descr = (ImageDescr *)ip;

        clearError();
        fits_update_key (im_descr->fptr, TFLOAT, keyword, &value,
                                NULL, &status);
        if (status != 0)
            setError (status, "c_imhadr:  error updating keyword");
}

void c_imhadi (IRAFPointer ip, char *keyword, int value) {

/* Update or add an integer keyword to a header.
arguments:
IRAFPointer ip          i: image descriptor
char *keyword           i: keyword name
int value               i: value for the keyword
*/

        ImageDescr *im_descr;
        int status = 0;

        im_descr = (ImageDescr *)ip;

        clearError();
        fits_update_key (im_descr->fptr, TINT, keyword, &value,
                                NULL, &status);
        if (status != 0)
            setError (status, "c_imhadi:  error updating keyword");
}

void c_imastr (IRAFPointer ip, char *keyword, char *text) {

/* Update or add a string keyword to a header.
arguments:
IRAFPointer ip          i: image descriptor
char *keyword           i: keyword name
char *text              i: value for the keyword
*/

        ImageDescr *im_descr;
        int status = 0;

        im_descr = (ImageDescr *)ip;

        clearError();
        fits_update_key (im_descr->fptr, TSTRING, keyword, text,
                                NULL, &status);
        if (status != 0)
            setError (status, "c_imhadt:  error updating keyword");
}

void c_imputh (IRAFPointer ip, char *keyword, char *text) {

/* Adds a HISTORY or COMMENT keyword to a header.
arguments:
IRAFPointer ip          i: image descriptor
char *keyword           i: keyword name (should be HISTORY or COMMENT)
char *text              i: value for the keyword
*/

        ImageDescr *im_descr;
        int status = 0;

        im_descr = (ImageDescr *)ip;

        /* only accept HISTORY or COMMENT keyword additions */
        clearError();
        if (strcmp(keyword,"HISTORY")==0) {
           fits_write_history (im_descr->fptr, text, &status);
        }
        else if (strcmp(keyword,"COMMENT")==0) {
           fits_write_comment (im_descr->fptr, text, &status);
        }
        else {
            setError (0, "c_imputh: Only supports HISTORY or COMMENT keywords");
        }
        if (status != 0)
            setError (status, "c_imputh:  error updating HISTORY or COMMENT keyword");
}
