# include <stdlib.h>
# include <string.h>
# include <fitsio.h>
# include "cimages.h"

IRAFPointer c_immap (char *imagename, int iomode, IRAFPointer tp_template) {

/* Open a image.
arguments:
char *imagename         i: name of image; may include extname or HDU number
                           in brackets (HDU = 0 is the primary HDU)
int iomode              i: IRAF I/O mode:  IRAF_READ_ONLY, IRAF_READ_WRITE,
                           IRAF_NEW_FILE, IRAF_NEW_COPY
IRAFPointer tp_template    i: usually NULL (or 0), but if iomode is IRAF_NEW_COPY
                           this is the image descriptor for the template
function value          o: image descriptor
*/

        IRAFPointer ip;
        ImageDescr *im_descr;
        char *fullname;         /* name with environment variable resolved */
        char *brackets;         /* expression in brackets, or NULL */
        int hdunum;             /* HDU number (1 for primary HDU) */
        int hdutype;            /* type of HDU */
        fitsfile *fptr;         /* CFITSIO pointer */
        int cf_iomode;          /* CFITSIO I/O mode */
        int status = 0;
        char _ERROR_MSG[256];

        clearError();

        /* expand environment variable (if any) in imagename */
        fullname = (char *)calloc (SZ_FNAME+1, sizeof(char));
        clearError();
        status = c_vfn2osfn (imagename, fullname);
        if (status != 0) {
            setError (status, "c_immap:  error from c_vfn2osfn");
            return NULL;
        }

        ip = init_ip();
        im_descr = (ImageDescr *)ip;

        strcpy (im_descr->imagename, imagename);
        strcpy (im_descr->fullname, fullname);
        brackets = strchr (fullname, '[');
        if (brackets == NULL) {
            im_descr->brackets[0] = '\0';
            strcpy (im_descr->filename, fullname);
        } else {
            int n;
            strcpy (im_descr->brackets, brackets);
            n = brackets - fullname;
            copyString (im_descr->filename, fullname, n);
        }
        im_descr->iomode = iomode;
        free (fullname); fullname=NULL;

        if (iomode == IRAF_READ_ONLY || iomode == IRAF_READ_WRITE) {
            if (iomode == IRAF_READ_ONLY)
                cf_iomode = READONLY;
            else
                cf_iomode = READWRITE;

            /* fits_open_file = ffopen */
            clearError();
            fits_open_file (&fptr, im_descr->fullname, cf_iomode, &status);
            if (status != 0) {
                fits_get_errstatus(status, _ERROR_MSG);
                fprintf(stderr,"fits_open_file: %s\n",_ERROR_MSG);
                setError (status, "c_immap:  couldn't open file");
                free_ip (ip);
                return NULL;
            }

            im_descr->fptr = fptr;
            im_descr->tp_template = NULL;         /* no template */
            im_descr->image_exists = 1;        /* the image does exist */

            /* fits_get_hdu_num = ffghdn */
            fits_get_hdu_num (fptr, &hdunum);   /* primary HDU is hdunum = 1 */
            if (im_descr->brackets != NULL &&
                strncmp (im_descr->brackets, "[0]", 3) == 0) {
                im_descr->hdunum = hdunum;
                im_descr->hdutype = IMAGE_HDU;
                im_descr->nrows = 0;
                im_descr->ncols = 0;
            } else {
                if (hdunum == 1) {
                    hdunum = 2;
                    /* fits_movabs_hdu = ffmahd */
                    clearError();
                    fits_movabs_hdu (fptr, hdunum, &hdutype, &status);
                    if (status != 0) {
                        setError (status, "c_immap:");
                        free_ip (ip);
                        return NULL;
                    }
                }
                im_descr->hdunum = hdunum;
                im_descr->hdutype = hdutype;
            }

        } else {
            im_descr->tp_template = tp_template;
            /* the image hasn't actually been created yet */
            im_descr->image_exists = 0;
            im_descr->nrows = 0;
            if (iomode == IRAF_NEW_COPY)
                // FOR NOW treat this as unimplemented...
                //imCopyTmpl (ip);        /* copy column info from template */
                setError (0, "c_immap: Image templates not yet implemented");
                free_ip (ip);
                return NULL;
        }

        return ip;
}
