# include <stdio.h>
# include <stdlib.h>
# include <fitsio.h>
# include "cimages.h"

/* This is a set of functions used by the images C interface functions.
   The prototypes for these are in cimages.h.

    ImageDescr *im_descr       pointer to a image descriptor
    IRAFPointer ip              (void *)im_descr

    ip = init_ip();
    free_ip (ip);

    im_descr = (ImageDescr *)ip;

    When c_immap is called, a im_descr is created that points to a struct
    with information about the image.  c_immap returns ip, which is a pointer
    to this object, but cast to void *.  ip is input to almost every other
    image I/O function.

    The reason that ip is a pointer to void is so it can be
    defined as of type IRAFPointer.
*/

static void freeImageP (IRAFPointer ip);

/* create a ip (image pointer), and initialize to default values */
IRAFPointer init_ip (void) {

        ImageDescr *im_descr;
        IRAFPointer ip;

        im_descr = (ImageDescr *)calloc (1, sizeof(ImageDescr));
        im_descr->imagename = (char *)calloc (SZ_FNAME+1, sizeof(char));
        im_descr->fullname = (char *)calloc (SZ_FNAME+1, sizeof(char));
        im_descr->filename = (char *)calloc (SZ_FNAME+1, sizeof(char));
        im_descr->brackets = (char *)calloc (SZ_FNAME+1, sizeof(char));
        im_descr->fptr = NULL;
        im_descr->tp_template = NULL;
        im_descr->image_exists = 0;
        im_descr->iomode = IRAF_READ_ONLY;
        im_descr->hdunum = -1;
        im_descr->hdutype = -1;
        im_descr->nrows = 0;
        im_descr->ncols = 0;

        ip = (void *)im_descr;

        return ip;
}

/* free a ip (image pointer) */
void free_ip (IRAFPointer ip) {
        freeImageP (ip);
}

/* free memory for a image pointer */
static void freeImageP (IRAFPointer ip) {

        ImageDescr *im_descr;
        int i;

        im_descr = (ImageDescr *)ip;
        if (im_descr != NULL) {
            /* free memory for strings */
            if (im_descr->imagename != NULL) {
                free (im_descr->imagename); im_descr->imagename=NULL;
            }
            if (im_descr->fullname != NULL) {
                free (im_descr->fullname); im_descr->fullname=NULL;
            }
            if (im_descr->brackets != NULL) {
                free (im_descr->brackets); im_descr->brackets=NULL;
            }
        }
        free (im_descr); im_descr=NULL;
}
