#! /bin/sh
# 
# Name: alert_a_sql.s
#
# Description: Looks for *_file table entries that have an empty 
#              opus_load_date or archive_date (a 2-day allowance is
#              made so that the most recent in-progress deliveries aren't
#              reported yet). 
#
#              NOTE: Particular delivery numbers are skipped in each
#                    date check, probably because they are known problem 
#                    cases that will never be resolved.
#
# Usage: alert_a_sql.s INSTRUMENT_PREFIX (e.g. acs, stis, nic, etc.)
#
#--------------------------------------------------------------------------
isql -S$CDBS_SERVER << EOF 
use $CDBS_DB
go

/* Check that no deliveries have unset dates */

if  exists (select * from $1_file 
            where opus_load_date is null and 
                  opus_flag = 'Y' and 
                  datediff(day, general_availability_date, getdate()) > 2
                  and
                  delivery_number not in (
           10465,
           12106
             )
           )

begin
 print '-> No response from OPUS set for $1 delivery'
 print '->     file name        delivery_date            delivery_number'
 select distinct '->', convert(char(20), file_name), general_availability_date, delivery_number
         from $1_file f
         where opus_load_date is null and 
               opus_flag = 'Y' and
               datediff(day, general_availability_date, getdate()) > 2
               and
               delivery_number not in (
           10465,
           12106
             )
 print '-> '
end


if  exists (select * from $1_file 
            where archive_date is null and 
                  opus_flag = 'Y' and 
                  datediff(day, general_availability_date, getdate()) > 2
                  and
                  delivery_number not in (
           10465,
           10572,
           10574,
           10575,
           10576,
           10577,
           10578,
           10579,
           10582,
           10583,
           10584,
           10585,
           10607, 
           10761,
           10793,
           10852,
           11724,
           12106
             )
           )

begin
 print '-> No response from DADS for $1 delivery'
 print '->     file name        delivery_date            delivery_number'
 select distinct '->', convert(char(20), file_name), general_availability_date, delivery_number
         from $1_file f
            where archive_date is null and 
                  opus_flag = 'Y' and 
                  datediff(day, general_availability_date, getdate()) > 2
                  and
                  delivery_number not in (
           10465,
           10572,
           10574,
           10575,
           10576,
           10577,
           10578,
           10579,
           10582,
           10583,
           10584,
           10585,
           10607,
           10761,
           10793,
           10852,
           11724,
           12106
                 )
 print '-> '
end

go
