#! /bin/sh
#
# Name: cc_archive_date1_a.s
#
# Description: Verifies that all deliveries PRIOR TO the deliveryNumber
#              argument have their archive_date set in the 
#              {instrumentPrefix}_file DB table, EXCEPT for a list of
#              special-case deliveryNumbers that are excluded from the test
#              (assumed that those have good reasons that archive_date is
#               not set).
#
# Called by:  cc_archive_date1.s
#
# Requires:   env var CDBS_SERVER
#             env var CDBS_DB
#
# Usage:      cc_archive_date1_a.s instrumentPrefix deliveryNumber
#
#--------------------------------------------------------------------------
isql -S$CDBS_SERVER << EOF 
use $CDBS_DB
go

/* Check all deliveries have set archive_dates */

if  exists (select * from $1_file 
            where archive_date is null and
                  delivery_number < $2 and
                  delivery_number not in (
           10572,
           10574,
           10575,
           10576,
           10577,
           10578,
           10579,
           10582,
           10583,
           10584,
           10585,
           10607) 
           )
begin
 print '-> CDBS WARNING:'
 print '->  Archive date not set in previous $1 delivery'
 print '->      file name                                          delivery_number'
 select distinct '->', file_name, delivery_number 
         from $1_file f
         where archive_date is null and delivery_number < $2
                  and delivery_number not in (
           10572,
           10574,
           10575,
           10576,
           10577,
           10578,
           10579,
           10582,
           10583,
           10584,
           10585,
           10607) 
 print '->'
end
go
