#! /bin/sh
#
# Name: cc_check_cdbs.s
#
# Description: Runs a set of consistency-checking scripts against the
#              CDBS database and a CDBS delivery (either a passed
#              deliveryNumber or the last delivery number put into the 
#              database).
#
# Called by:   check_cdbs
#
# Returns:     none (the outputLogfile will be parsed in the caller to
#                    look for problems)
#
# Requires:    env var CDBS_SERVER
#              env var CDBS_DB
#
# Usage: cc_check_cdbs.s outputLogfile [deliveryNumber]
#                (will use latest delivery number if none given)
#
# History:
# 05/04/11  xxxxx  MSwam    ported to Linux/MSSQL and removed FOC/UNI check
#
#------------------------------------------------------------------------
export CDBS_DB CDBS_SERVER
echo "starting cdbs_check " > $1
echo "database " ${CDBS_DB?"CDBS_ERROR: CDBS_DB is undefined"} >> $1
echo "server " ${CDBS_SERVER?"CDBS_ERROR: CDBS_SERVER is undefined"} >> $1
date >> $1
echo "" >> $1
#
# determine the delivery number from the command args or DB content
if test $# -lt 2
then
 in_delivery=`cc_in_delivery.s | grep "within a delivery" | wc -l` 
 dn=`get_current_delivery_number.s | awk '/^ *[0-9]/{print $1}'`
 if test $in_delivery -eq 0
 then
  echo "No delivery in progress. Last delivery number $dn." >> $1
  echo "No delivery in progress. Last delivery number $dn."
  dnu=`expr $dn + 1`
 else
  echo "Delivery in progress. Current delivery number $dn." >> $1
  echo "delivery $dn in progress"
  dnu=$dn
 fi
else
  dn=$2
  echo "Setting effective current delivery number to $dn"
  echo "No delivery in progress. Last delivery number $dn." >> $1
  dnu=$dn
fi
#
# apply the various consistency checks
echo "" >> $1
echo "STIS missing modes check" >> $1
echo "STIS missing modes check" 
cc_missing_modes.s $dnu | fgrep "-" >> $1
#
echo "" >> $1
echo "synphot compname check" >> $1
echo "synphot compname check" 
cc_syn_comp.s $dnu | fgrep "-" >> $1
#
echo "" >> $1
echo "expansion number check" >> $1
echo "expansion number check" 
cc_expansion_number1.s | fgrep "-" >> $1
#
echo "" >> $1
echo "archive date check" >> $1
echo "archive date check" 
cc_archive_date1.s $dnu | fgrep "-" >> $1
#
echo "" >> $1
echo "general availability date check" >> $1
echo "general availability date check" 
cc_ga_date1.s $dnu | fgrep "-" >> $1
#
echo "" >> $1
echo "opus load date check 1" >> $1
echo "opus load date check 1" 
cc_opus_load_date1.s | fgrep "-" >> $1
#
echo "" >> $1
echo "opus load date check 2" >> $1
echo "opus load date check 2" 
cc_opus_load_date2.s $dnu | fgrep "-" >> $1
#
echo "row check" >> $1
echo "row check"
cc_row_check1.s | fgrep "-" >> $1
#
echo "" >> $1
echo "" >> $1
echo "file check" >> $1
echo "file check"
cc_file_check1.s | fgrep "-" >> $1
#
echo "" >> $1
echo "reject check 1" >> $1
echo "reject check 1" 
cc_reject1.s | fgrep "-" >> $1
#
echo "" >> $1
echo "reject check 2" >> $1
echo "reject check 2" 
cc_reject2.s | fgrep "-" >> $1
#
echo "" >> $1
case $2 in
 -f) echo "full reject check 3" >> $1; \
     echo "full reject check 3"; \
     cc_reject3.s >> $1 |  fgrep "-" ; \
     echo ""; \
     echo "full delivery number check" >> $1; \
     echo "full delivery number check"; \
     cc_dn.s |  fgrep "-" >> $1;;
 -c|*) echo "current reject check 3" >> $1; \
       echo "current reject check 3"; \
     echo "delivery number $dn" >> $1; \
     cc_reject3_curr.s $dn |  fgrep "-" >> $1; \
     echo "" >> $1; \
     echo "current delivery number check" >> $1; \
     echo "current delivery number check"; \
     cc_dn_curr.s $dn |  fgrep "-" >> $1;;
 esac
#
echo "" >> $1
echo "reject check 4" >> $1
echo "reject check 4"
echo "delivery number $dn" >> $1
cc_reject4.s $dn |  fgrep "-" >> $1
#
# DONE
echo "" >> $1
echo "cdbs_check completed" >> $1
date >> $1
