#! /bin/sh
#
# Name:  cc_dn_curr.s
#
# Description: Check that no two files have the same
#              reference_file_type, mode, and useafter_date in the
#              current delivery.
#
# Called by:   cc_check_cdbs.s
#
# Requires:    env var CDBS_SERVER
#              env var CDBS_DB
#
#---------------------------------------------------------------------------
isql -S$CDBS_SERVER << EOF 
use $CDBS_DB
go

/*======*/
/* COS */
/*======*/
if exists (select * from cos_row r1, cos_row r2, 
           cos_file f1, cos_file f2
     where
      r1.detector = r2.detector and 
      r1.obstype = r2.obstype and
      r1.obsmode = r2.obsmode and 
      r1.segment = r2.segment and
      r1.cenwave = r2.cenwave and
      r1.aperture= r2.aperture and
      r1.opt_elem  = r2.opt_elem  and
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      $1 = f1.delivery_number and
      $1 = f2.delivery_number and
      f1.reference_file_type = f2.reference_file_type and
      f1.file_name < f2.file_name )
begin
 print '-> CDBS ERROR:'
 print '->  2 cos files with the same type, mode, and useafter_date in delivery'
 select distinct '->', f1.file_name, f2.file_name from cos_row r1, cos_row r2, 
           cos_file f1, cos_file f2
     where
      r1.detector = r2.detector and 
      r1.obstype = r2.obstype and
      r1.obsmode = r2.obsmode and 
      r1.segment = r2.segment and
      r1.cenwave = r2.cenwave and
      r1.aperture= r2.aperture and
      r1.opt_elem  = r2.opt_elem  and
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      $1 = f1.delivery_number and
      $1 = f2.delivery_number and
      f1.reference_file_type = f2.reference_file_type and
      f1.file_name < f2.file_name 
end
go

/*======*/
/* STIS */
/*======*/
if exists (select * from stis_row r1, stis_row r2, 
           stis_file f1, stis_file f2
     where
      r1.detector = r2.detector and 
      r1.ccdamp = r2.ccdamp and 
      r1.ccdgain = r2.ccdgain and
      r1.ccdoffst = r2.ccdoffst and
      r1.binaxis1 = r2.binaxis1 and
      r1.binaxis2 = r2.binaxis2 and
      r1.opt_elem  = r2.opt_elem  and
      r1.obstype = r2.obstype and
      r1.aperture= r2.aperture and
      r1.cenwave = r2.cenwave and
      r1.sclamp = r2.sclamp and
      r1.lampset = r2.lampset and
      r1.filter = r2.filter and
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      $1 = f1.delivery_number and
      $1 = f2.delivery_number and
      f1.reference_file_type = f2.reference_file_type and
      f1.file_name < f2.file_name )
begin
 print '-> CDBS ERROR:'
 print '->  2 stis files with the same type, mode, and useafter_date in delivery'
 select distinct '->', f1.file_name, f2.file_name from stis_row r1, stis_row r2, 
           stis_file f1, stis_file f2
     where
      r1.detector = r2.detector and 
      r1.ccdamp = r2.ccdamp and 
      r1.ccdgain = r2.ccdgain and
      r1.ccdoffst = r2.ccdoffst and
      r1.binaxis1 = r2.binaxis1 and
      r1.binaxis2 = r2.binaxis2 and
      r1.opt_elem  = r2.opt_elem  and
      r1.obstype = r2.obstype and
      r1.aperture= r2.aperture and
      r1.cenwave = r2.cenwave and
      r1.sclamp = r2.sclamp and
      r1.lampset = r2.lampset and
      r1.filter = r2.filter and
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      $1 = f1.delivery_number and
      $1 = f2.delivery_number and
      f1.reference_file_type = f2.reference_file_type and
      f1.file_name < f2.file_name 
end
go

/*======*/
/* ACS */
/*======*/
if exists (select * from acs_row r1, acs_row r2, 
           acs_file f1, acs_file f2
     where
      r1.detector = r2.detector and 
      r1.ccdchip   = r2.ccdchip and 
      r1.ccdamp = r2.ccdamp and 
      r1.ccdgain = r2.ccdgain and
      r1.filter1  = r2.filter1 and
      r1.filter2  = r2.filter2 and
      r1.flashcur = r2.flashcur and
      r1.shutrpos = r2.shutrpos and
      r1.detchip = r2.detchip and
      r1.direction = r2.direction and
      r1.wavelength = r2.wavelength and
      r1.obstype = r2.obstype and
      r1.naxis1 = r2.naxis1 and
      r1.naxis2 = r2.naxis2 and
      r1.ltv1 = r2.ltv1 and
      r1.ltv2 = r2.ltv2 and
      r1.fw1offst = r2.fw1offst and
      r1.fw2offst = r2.fw2offst and
      r1.fwsoffst = r2.fwsoffst and
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      $1 = f1.delivery_number and
      $1 = f2.delivery_number and
      f1.reference_file_type = f2.reference_file_type and
      f1.file_name < f2.file_name )
begin
 print '-> CDBS ERROR:'
 print '->  2 acs files with the same type, mode, and useafter_date in delivery'
 select distinct '->', f1.file_name, f2.file_name from acs_row r1, acs_row r2, 
           acs_file f1, acs_file f2
     where
      r1.detector = r2.detector and 
      r1.ccdchip   = r2.ccdchip and 
      r1.ccdamp = r2.ccdamp and 
      r1.ccdgain = r2.ccdgain and
      r1.filter1  = r2.filter1 and
      r1.filter2  = r2.filter2 and
      r1.flashcur = r2.flashcur and
      r1.shutrpos = r2.shutrpos and
      r1.detchip = r2.detchip and
      r1.direction = r2.direction and
      r1.wavelength = r2.wavelength and
      r1.obstype = r2.obstype and
      r1.naxis1 = r2.naxis1 and
      r1.naxis2 = r2.naxis2 and
      r1.ltv1 = r2.ltv1 and
      r1.ltv2 = r2.ltv2 and
      r1.fw1offst = r2.fw1offst and
      r1.fw2offst = r2.fw2offst and
      r1.fwsoffst = r2.fwsoffst and
      f1.file_name = r1.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      $1 = f1.delivery_number and
      $1 = f2.delivery_number and
      f1.reference_file_type = f2.reference_file_type and
      f1.file_name < f2.file_name 
end
go

/*======*/
/* WFC3 */
/*======*/
if exists (select * from wfc3_row r1, wfc3_row r2, 
           wfc3_file f1, wfc3_file f2
     where
      r1.detector = r2.detector and 
      r1.ccdamp = r2.ccdamp and 
      r1.ccdgain = r2.ccdgain and
      r1.binaxis1 = r2.binaxis1 and
      r1.binaxis2 = r2.binaxis2 and
      r1.samp_seq = r2.samp_seq and
      r1.subtype = r2.subtype and
      r1.filter  = r2.filter and
      r1.ccdchip   = r2.ccdchip and 
      r1.ccdofsta = r2.ccdofsta and
      r1.ccdofstb = r2.ccdofstb and
      r1.ccdofstc = r2.ccdofstc and
      r1.ccdofstd = r2.ccdofstd and
      r1.crsplit = r2.crsplit and
      r1.binx = r2.binx and
      r1.biny = r2.biny and
      r1.detchip = r2.detchip and
      r1.meanexp = r2.meanexp and
      r1.aperture = r2.aperture and
      r1.direction = r2.direction and
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      $1 = f1.delivery_number and
      $1 = f2.delivery_number and
      f1.reference_file_type = f2.reference_file_type and
      f1.file_name < f2.file_name )
begin
 print '-> CDBS ERROR:'
 print '->  2 wfc3 files with the same type, mode, and useafter_date in delivery'
 select distinct '->', f1.file_name, f2.file_name from wfc3_row r1, wfc3_row r2, 
           wfc3_file f1, wfc3_file f2
     where
      r1.detector = r2.detector and 
      r1.ccdamp = r2.ccdamp and 
      r1.ccdgain = r2.ccdgain and
      r1.binaxis1 = r2.binaxis1 and
      r1.binaxis2 = r2.binaxis2 and
      r1.samp_seq = r2.samp_seq and
      r1.subtype = r2.subtype and
      r1.filter  = r2.filter and
      r1.ccdchip   = r2.ccdchip and 
      r1.ccdofsta = r2.ccdofsta and
      r1.ccdofstb = r2.ccdofstb and
      r1.ccdofstc = r2.ccdofstc and
      r1.ccdofstd = r2.ccdofstd and
      r1.crsplit = r2.crsplit and
      r1.binx = r2.binx and
      r1.biny = r2.biny and
      r1.detchip = r2.detchip and
      r1.meanexp = r2.meanexp and
      r1.aperture = r2.aperture and
      r1.direction = r2.direction and
      f1.file_name = r1.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      $1 = f1.delivery_number and
      $1 = f2.delivery_number and
      f1.reference_file_type = f2.reference_file_type and
      f1.file_name < f2.file_name 
end
go

/*=======*/
/* WFPC2 */
/*=======*/
if exists (select * from wfpc2_row r1, wfpc2_row r2, 
           wfpc2_file f1, wfpc2_file f2
     where
      r1.atodgain = r2.atodgain and 
      r1.mode = r2.mode and 
      r1.serials = r2.serials and
      r1.shutter = r2.shutter and
      r1.filter1 = r2.filter1 and
      r1.filter2 = r2.filter2 and
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      $1 = f1.delivery_number and
      $1 = f2.delivery_number and
      f1.reference_file_type = f2.reference_file_type and
      f1.file_name < f2.file_name )
begin
 print '-> CDBS ERROR:'
 print '->  2 wfpc2 files with the same type, mode, and useafter_date in delivery'
 select distinct '->', f1.file_name, f2.file_name from wfpc2_row r1, wfpc2_row r2, 
           wfpc2_file f1, wfpc2_file f2
     where
      r1.atodgain = r2.atodgain and 
      r1.mode = r2.mode and 
      r1.serials = r2.serials and
      r1.shutter = r2.shutter and
      r1.filter1 = r2.filter1 and
      r1.filter2 = r2.filter2 and
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      $1 = f1.delivery_number and
      $1 = f2.delivery_number and
      f1.reference_file_type = f2.reference_file_type and
      f1.file_name < f2.file_name 
end
go

/*=======*/
/* NIC */
/*=======*/
if exists (select * from nic_row r1, nic_row r2, 
           nic_file f1, nic_file f2
     where
      r1.camera = r2.camera and 
      r1.filter = r2.filter and 
      r1.readout = r2.readout and
      r1.nread = r2.nread and
      r1.obsmode = r2.obsmode and
      r1.samp_seq = r2.samp_seq and
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      $1 = f1.delivery_number and
      $1 = f2.delivery_number and
      f1.reference_file_type = f2.reference_file_type and
      f1.file_name < f2.file_name )
begin
 print '-> CDBS ERROR:'
 print '->  2 nic files with the same type, mode, and useafter_date in delivery'
 select distinct '->', f1.file_name, f2.file_name from nic_row r1, nic_row r2, 
           nic_file f1, nic_file f2
     where
      r1.camera = r2.camera and 
      r1.filter = r2.filter and 
      r1.readout = r2.readout and
      r1.nread = r2.nread and
      r1.obsmode = r2.obsmode and
      r1.samp_seq = r2.samp_seq and
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      $1 = f1.delivery_number and
      $1 = f2.delivery_number and
      f1.reference_file_type = f2.reference_file_type and
      f1.file_name < f2.file_name 
end
go

/*=========*/
/* SYNPHOT */
/*=========*/
if exists (select * from synphot_row r1, synphot_row r2, 
           synphot_file f1, synphot_file f2
     where
      r1.compname = r2.compname and 
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      $1 = f1.delivery_number and
      $1 = f2.delivery_number and
      f1.reference_file_type = f2.reference_file_type and
      f1.file_name < f2.file_name )
begin
 print '-> CDBS ERROR:'
 print '->  2 synphot files with the same type, mode, and useafter_date in delivery'
 select distinct '->', f1.file_name, f2.file_name from synphot_row r1, synphot_row r2, 
           synphot_file f1, synphot_file f2
     where
      r1.compname = r2.compname and 
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      $1 = f1.delivery_number and
      $1 = f2.delivery_number and
      f1.reference_file_type = f2.reference_file_type and
      f1.file_name < f2.file_name 
end
go

/*=========*/
/* MULTI */
/*=========*/
if exists (select * from multi_row r1, multi_row r2, 
           multi_file f1, multi_file f2
     where
      r1.targetid = r2.targetid and 
      r1.fld_name = r2.fld_name and 
      r1.obsmode = r2.obsmode and 
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      $1 = f1.delivery_number and
      $1 = f2.delivery_number and
      f1.reference_file_type = f2.reference_file_type and
      f1.file_name < f2.file_name )
begin
 print '-> CDBS ERROR:'
 print '->  2 multi files with the same type, mode, and useafter_date in delivery'
 select distinct '->', f1.file_name, f2.file_name from multi_row r1, multi_row r2, 
           multi_file f1, multi_file f2
     where
      r1.targetid = r2.targetid and 
      r1.fld_name = r2.fld_name and 
      r1.obsmode = r2.obsmode and 
      f1.file_name = r1.file_name and
      f1.expansion_number = r1.expansion_number and
      f2.file_name = r2.file_name and
      f2.expansion_number = r2.expansion_number and
      f1.useafter_date = f2.useafter_date and 
      $1 = f1.delivery_number and
      $1 = f2.delivery_number and
      f1.reference_file_type = f2.reference_file_type and
      f1.file_name < f2.file_name 
end
go
