#! /bin/sh
#
# Name: cc_missing_modes_a.s
#
# Description:  Looks for missing "modes" in the STIS file and row DB tables.
#               This is done by comparing the values of all of the file and
#               row selection fields (these are the "modes") between
#               the reference files in a delivery and the files listed
#               in the DB as the "comparison files" for those files.
#
#               NOTE: ONLY INSTRUMENT STIS IS DONE.
#
# Called by:    cc_missing_modes.s
#
# Requires:  env var CDBS_SERVER
#            env var CDBS_DB
#
# Usage:     cc_missing_modes_a.s deliveryNumber
#
#---------------------------------------------------------------------------
echo $1
isql -S$CDBS_SERVER << EOF 
use $CDBS_DB
go

create table #t (file_name varchar(50), comparison_file_name varchar(50) )

insert into #t 
select f.file_name, f.comparison_file_name
from stis_file f, relation_info r
where
      f.reference_file_type = r.reference_file_type and
      r.instrument = 'STIS' and
      r.type = 'T' and
      f.delivery_number = $1

/* See if the new data has a missing mode */
/* by checking the comparison file        */
if  exists (select *
 from stis_row r1, #t t
   where 
   r1.file_name = t.comparison_file_name and
   not exists (select * from stis_row r2
    where
   r1.detector = r2.detector and
   r1.ccdamp   = r2.ccdamp   and
   r1.ccdgain  = r2.ccdgain  and
   r1.ccdoffst = r2.ccdoffst and
   r1.binaxis1 = r2.binaxis1 and
   r1.binaxis2 = r2.binaxis2 and
   r1.opt_elem = r2.opt_elem and
   r1.obstype  = r2.obstype  and
   r1.aperture = r2.aperture and
   r1.cenwave  = r2.cenwave  and
   r1.sclamp   = r2.sclamp   and
   r1.lampset  = r2.lampset  and
   r1.filter   = r2.filter   and
   r2.delivery_number = $1   and
   r2.file_name = t.file_name) )
begin
 print '-> CDBS ERROR:'
 print '-> Missing modes in a newly delivered table'
 select '->',
   missing_in_file = t.file_name, 
   in_file = r1.file_name, 
   r1.detector,
   r1.ccdamp,
   r1.ccdgain,
   r1.ccdoffst,
   r1.binaxis1,
   r1.binaxis2,
   r1.opt_elem,
   r1.obstype,
   r1.aperture,
   r1.cenwave,
   r1.sclamp,
   r1.lampset,
   r1.filter
 from stis_row r1, #t t
   where 
   r1.file_name = t.comparison_file_name and
   not exists (select * from stis_row r2
    where
   r1.detector = r2.detector and
   r1.ccdamp   = r2.ccdamp   and
   r1.ccdgain  = r2.ccdgain  and
   r1.ccdoffst = r2.ccdoffst and
   r1.binaxis1 = r2.binaxis1 and
   r1.binaxis2 = r2.binaxis2 and
   r1.opt_elem = r2.opt_elem and
   r1.obstype  = r2.obstype  and
   r1.aperture = r2.aperture and
   r1.cenwave  = r2.cenwave  and
   r1.sclamp   = r2.sclamp   and
   r1.lampset  = r2.lampset  and
   r1.filter   = r2.filter   and
   r2.file_name = t.file_name)
end
go
qq
