#! /usr/bin/env python

import pyfits
import os
import glob

'''
This program is a replacement for setlodkeywd.cl
It populates the rows of a lod file with the OPUS_FLAG,
CHANGE_FLAG, and COMMENT sections. The file comment
is a combination of the descrip and history keyword. 
The row comment is NA. The row comment is a change from
setlodkeywd.cl which left the row comment blank.
The lod file is modfied in place

Version 1.0
Date: March 07, 2011
By: Azalee Bostroem

Call sequence:
	setlodkeywd.py
	
'''


def setlodkeyword(filename = None):
	#If no filename is specified - get all .lod files
	if filename == None:
		flist = glob.glob('*lod')
	#If a file name is specified, make sure it exists
	else:
		#Check for mistakes:
		current_dir = os.getcwd()
		fexist = os.path.exists(current_dir + '/' + filename)
		while fexist == False:
			filename = raw_input('ERROR: %s does not exist. Please enter the correct file name: ')
		flist = [filename]
		
	#For each file in the list:
	for filename in flist:
		run_file = raw_input('Run setlodkeywd for %s? (y)' %(filename))  #Check that you want to run setloadkeyword on file
		if run_file == '': run_file = 'y'
		if run_file != 'y':continue
		else:
			#Set the change level and Opus Flag
			CHANGE_LEVEL = raw_input('Enter Change level (default = SEVERE): ') 
			if CHANGE_LEVEL == '': CHANGE_LEVEL = 'SEVERE'
			CHANGE_LEVEL = str(CHANGE_LEVEL).upper() #Make sure change level is in capital letters
			
			OPUS_FLAG = raw_input('Enter Opus Flag (default = Y): ')
			if OPUS_FLAG == '': OPUS_FLAG = 'Y'
			OPUS_FLAG = str(OPUS_FLAG).upper() #Make sure opus_flag is in capital letters
			
			#Check that CHANGE_LEVEL and OPUS_FLAG are valid entries
			while (CHANGE_LEVEL != 'SEVERE') & (CHANGE_LEVEL != 'MODERATE') & (CHANGE_LEVEL != 'TRIVIAL'):
				CHANGE_LEVEL = raw_input('ERROR: %s is not a valid entry. Please enter change level (SEVERE, MODERATE, TRIVIAL): ' %(CHANGE_LEVEL))
			while (OPUS_FLAG != 'Y') & (OPUS_FLAG != 'N'):
				OPUS_FLAG = raw_input('ERROR: %s is not a valid entry. Please enter opus flag (Y, N): ' %(OPUS_FLAG))
			
	
			#Start to modify file
			#Open fits file to get the history and description
			ofile = pyfits.open(filename[:-3]+'fits') 
			hdr = ofile[0].header
			hist = hdr.get_history()
			#Remove any leading blanks from the history section
			for i, h in enumerate(hist):
				if len(h) > 1:
					while h[0] == ' ':
						h = h[1:]
				hist[i] = h
			descr = hdr['DESCRIP']
			ofile.close()
			
			#Open and read in the lod file
			ld_file_r = open(filename, 'r')
			all_lines = ld_file_r.readlines()
			ld_file_r.close()
			#Open the lod file and erase the current contents
			ld_file_w = open(filename, 'w')	
			main_comment = 'n'  #This is to determine if the comment is the file comment or the row comment
			for iline in all_lines:  #Loop over lines
				#Check that there is only one comparison file
				if iline[0:10] == 'COMPARISON':
					if len(iline) > 40:
						print 'ERROR: There are more than one comparision files found:'
						for i in iline.split()[2:]:
							print '\t%s' %(i)
						comp_file = raw_input('Enter the file name of the comparision file:')
						new_line = iline[:-1]+ ' ' + comp_file+ ' \n'
						ld_file_w.write(new_line)
						
				#Fill in the OPUS_FLAG field
				if iline[0:4] == 'OPUS':
					new_line = iline[:-1]+OPUS_FLAG+'  \n'
					ld_file_w.write(new_line)
					
				#Fill in Comment section
				elif iline[0:7] == 'COMMENT':
					if main_comment == 'n':  #Case of file comment
						new_line = iline[:-1]+descr+'  \n'
						ld_file_w.write(new_line)
						for hist_line in hist:
							ld_file_w.write(hist_line+'  \n')
						main_comment = 'y'  #Case of row comment
					elif main_comment == 'y':
						new_line = iline[:-1] +' '+ 'NA  \n'
						ld_file_w.write(new_line)
						
				#Fill in CHANGE_LEVEL field
				elif iline[0:6] == 'CHANGE':
					new_line = iline[:-1]+ CHANGE_LEVEL + '  \n'
					ld_file_w.write(new_line)
				else:
					ld_file_w.write(iline)
			ld_file_w.close()
			

#If file is called from the command line, then execute this section
if __name__ == "__main__":
	ifile = raw_input('Enter filename (default is all .lod files): ')
	if ifile == '':
		setlodkeyword()
	else:
		setlodkeyword(filename = ifile)
			
	
	
